# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon SageMaker'
prefix = 'sagemaker'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTags = Action('AddTags')
AssociateTrialComponent = Action('AssociateTrialComponent')
BatchGetMetrics = Action('BatchGetMetrics')
BatchPutMetrics = Action('BatchPutMetrics')
CreateAlgorithm = Action('CreateAlgorithm')
CreateApp = Action('CreateApp')
CreateAutoMLJob = Action('CreateAutoMLJob')
CreateCodeRepository = Action('CreateCodeRepository')
CreateCompilationJob = Action('CreateCompilationJob')
CreateDomain = Action('CreateDomain')
CreateEndpoint = Action('CreateEndpoint')
CreateEndpointConfig = Action('CreateEndpointConfig')
CreateExperiment = Action('CreateExperiment')
CreateFlowDefinition = Action('CreateFlowDefinition')
CreateHumanTaskUi = Action('CreateHumanTaskUi')
CreateHyperParameterTuningJob = Action('CreateHyperParameterTuningJob')
CreateLabelingJob = Action('CreateLabelingJob')
CreateModel = Action('CreateModel')
CreateModelPackage = Action('CreateModelPackage')
CreateMonitoringSchedule = Action('CreateMonitoringSchedule')
CreateNotebookInstance = Action('CreateNotebookInstance')
CreateNotebookInstanceLifecycleConfig = \
    Action('CreateNotebookInstanceLifecycleConfig')
CreatePresignedDomainUrl = Action('CreatePresignedDomainUrl')
CreatePresignedNotebookInstanceUrl = \
    Action('CreatePresignedNotebookInstanceUrl')
CreateProcessingJob = Action('CreateProcessingJob')
CreateTrainingJob = Action('CreateTrainingJob')
CreateTransformJob = Action('CreateTransformJob')
CreateTrial = Action('CreateTrial')
CreateTrialComponent = Action('CreateTrialComponent')
CreateUserProfile = Action('CreateUserProfile')
CreateWorkforce = Action('CreateWorkforce')
CreateWorkteam = Action('CreateWorkteam')
DeleteAlgorithm = Action('DeleteAlgorithm')
DeleteApp = Action('DeleteApp')
DeleteCodeRepository = Action('DeleteCodeRepository')
DeleteDomain = Action('DeleteDomain')
DeleteEndpoint = Action('DeleteEndpoint')
DeleteEndpointConfig = Action('DeleteEndpointConfig')
DeleteExperiment = Action('DeleteExperiment')
DeleteFlowDefinition = Action('DeleteFlowDefinition')
DeleteHumanLoop = Action('DeleteHumanLoop')
DeleteModel = Action('DeleteModel')
DeleteModelPackage = Action('DeleteModelPackage')
DeleteMonitoringSchedule = Action('DeleteMonitoringSchedule')
DeleteNotebookInstance = Action('DeleteNotebookInstance')
DeleteNotebookInstanceLifecycleConfig = \
    Action('DeleteNotebookInstanceLifecycleConfig')
DeleteTags = Action('DeleteTags')
DeleteTrial = Action('DeleteTrial')
DeleteTrialComponent = Action('DeleteTrialComponent')
DeleteUserProfile = Action('DeleteUserProfile')
DeleteWorkforce = Action('DeleteWorkforce')
DeleteWorkteam = Action('DeleteWorkteam')
DescribeAlgorithm = Action('DescribeAlgorithm')
DescribeApp = Action('DescribeApp')
DescribeAutoMLJob = Action('DescribeAutoMLJob')
DescribeCodeRepository = Action('DescribeCodeRepository')
DescribeCompilationJob = Action('DescribeCompilationJob')
DescribeDomain = Action('DescribeDomain')
DescribeEndpoint = Action('DescribeEndpoint')
DescribeEndpointConfig = Action('DescribeEndpointConfig')
DescribeExperiment = Action('DescribeExperiment')
DescribeFlowDefinition = Action('DescribeFlowDefinition')
DescribeHumanLoop = Action('DescribeHumanLoop')
DescribeHumanTaskUi = Action('DescribeHumanTaskUi')
DescribeHyperParameterTuningJob = \
    Action('DescribeHyperParameterTuningJob')
DescribeLabelingJob = Action('DescribeLabelingJob')
DescribeModel = Action('DescribeModel')
DescribeModelPackage = Action('DescribeModelPackage')
DescribeMonitoringSchedule = Action('DescribeMonitoringSchedule')
DescribeNotebookInstance = Action('DescribeNotebookInstance')
DescribeNotebookInstanceLifecycleConfig = \
    Action('DescribeNotebookInstanceLifecycleConfig')
DescribeProcessingJob = Action('DescribeProcessingJob')
DescribeSubscribedWorkteam = Action('DescribeSubscribedWorkteam')
DescribeTrainingJob = Action('DescribeTrainingJob')
DescribeTransformJob = Action('DescribeTransformJob')
DescribeTrial = Action('DescribeTrial')
DescribeTrialComponent = Action('DescribeTrialComponent')
DescribeUserProfile = Action('DescribeUserProfile')
DescribeWorkforce = Action('DescribeWorkforce')
DescribeWorkteam = Action('DescribeWorkteam')
DisassociateTrialComponent = Action('DisassociateTrialComponent')
GetSearchSuggestions = Action('GetSearchSuggestions')
InvokeEndpoint = Action('InvokeEndpoint')
ListAlgorithms = Action('ListAlgorithms')
ListApps = Action('ListApps')
ListAutoMLJobs = Action('ListAutoMLJobs')
ListCandidatesForAutoMLJob = Action('ListCandidatesForAutoMLJob')
ListCodeRepositories = Action('ListCodeRepositories')
ListCompilationJobs = Action('ListCompilationJobs')
ListDomains = Action('ListDomains')
ListEndpointConfigs = Action('ListEndpointConfigs')
ListEndpoints = Action('ListEndpoints')
ListExperiments = Action('ListExperiments')
ListFlowDefinitions = Action('ListFlowDefinitions')
ListHumanLoops = Action('ListHumanLoops')
ListHumanTaskUis = Action('ListHumanTaskUis')
ListHyperParameterTuningJobs = Action('ListHyperParameterTuningJobs')
ListLabelingJobs = Action('ListLabelingJobs')
ListLabelingJobsForWorkteam = Action('ListLabelingJobsForWorkteam')
ListModelPackages = Action('ListModelPackages')
ListModels = Action('ListModels')
ListMonitoringExecutions = Action('ListMonitoringExecutions')
ListMonitoringSchedules = Action('ListMonitoringSchedules')
ListNotebookInstanceLifecycleConfigs = \
    Action('ListNotebookInstanceLifecycleConfigs')
ListNotebookInstances = Action('ListNotebookInstances')
ListProcessingJobs = Action('ListProcessingJobs')
ListSubscribedWorkteams = Action('ListSubscribedWorkteams')
ListTags = Action('ListTags')
ListTrainingJobs = Action('ListTrainingJobs')
ListTrainingJobsForHyperParameterTuningJob = \
    Action('ListTrainingJobsForHyperParameterTuningJob')
ListTransformJobs = Action('ListTransformJobs')
ListTrialComponents = Action('ListTrialComponents')
ListTrials = Action('ListTrials')
ListUserProfiles = Action('ListUserProfiles')
ListWorkforces = Action('ListWorkforces')
ListWorkteams = Action('ListWorkteams')
RenderUiTemplate = Action('RenderUiTemplate')
Search = Action('Search')
StartHumanLoop = Action('StartHumanLoop')
StartMonitoringSchedule = Action('StartMonitoringSchedule')
StartNotebookInstance = Action('StartNotebookInstance')
StopAutoMLJob = Action('StopAutoMLJob')
StopCompilationJob = Action('StopCompilationJob')
StopHumanLoop = Action('StopHumanLoop')
StopHyperParameterTuningJob = Action('StopHyperParameterTuningJob')
StopLabelingJob = Action('StopLabelingJob')
StopMonitoringSchedule = Action('StopMonitoringSchedule')
StopNotebookInstance = Action('StopNotebookInstance')
StopProcessingJob = Action('StopProcessingJob')
StopTrainingJob = Action('StopTrainingJob')
StopTransformJob = Action('StopTransformJob')
UpdateCodeRepository = Action('UpdateCodeRepository')
UpdateDomain = Action('UpdateDomain')
UpdateEndpoint = Action('UpdateEndpoint')
UpdateEndpointWeightsAndCapacities = \
    Action('UpdateEndpointWeightsAndCapacities')
UpdateExperiment = Action('UpdateExperiment')
UpdateMonitoringSchedule = Action('UpdateMonitoringSchedule')
UpdateNotebookInstance = Action('UpdateNotebookInstance')
UpdateNotebookInstanceLifecycleConfig = \
    Action('UpdateNotebookInstanceLifecycleConfig')
UpdateTrial = Action('UpdateTrial')
UpdateTrialComponent = Action('UpdateTrialComponent')
UpdateUserProfile = Action('UpdateUserProfile')
UpdateWorkforce = Action('UpdateWorkforce')
UpdateWorkteam = Action('UpdateWorkteam')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Transfer for SFTP'
prefix = 'transfer'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateServer = Action('CreateServer')
CreateUser = Action('CreateUser')
DeleteServer = Action('DeleteServer')
DeleteSshPublicKey = Action('DeleteSshPublicKey')
DeleteUser = Action('DeleteUser')
DescribeServer = Action('DescribeServer')
DescribeUser = Action('DescribeUser')
ImportSshPublicKey = Action('ImportSshPublicKey')
ListServers = Action('ListServers')
ListTagsForResource = Action('ListTagsForResource')
ListUsers = Action('ListUsers')
StartServer = Action('StartServer')
StopServer = Action('StopServer')
TagResource = Action('TagResource')
TestIdentityProvider = Action('TestIdentityProvider')
UntagResource = Action('UntagResource')
UpdateServer = Action('UpdateServer')
UpdateUser = Action('UpdateUser')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Glue'
prefix = 'glue'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchCreatePartition = Action('BatchCreatePartition')
BatchDeleteConnection = Action('BatchDeleteConnection')
BatchDeletePartition = Action('BatchDeletePartition')
BatchDeleteTable = Action('BatchDeleteTable')
BatchDeleteTableVersion = Action('BatchDeleteTableVersion')
BatchGetCrawlers = Action('BatchGetCrawlers')
BatchGetDevEndpoints = Action('BatchGetDevEndpoints')
BatchGetJobs = Action('BatchGetJobs')
BatchGetPartition = Action('BatchGetPartition')
BatchGetTriggers = Action('BatchGetTriggers')
BatchGetWorkflows = Action('BatchGetWorkflows')
BatchStopJobRun = Action('BatchStopJobRun')
CancelMLTaskRun = Action('CancelMLTaskRun')
CreateClassifier = Action('CreateClassifier')
CreateConnection = Action('CreateConnection')
CreateCrawler = Action('CreateCrawler')
CreateDatabase = Action('CreateDatabase')
CreateDevEndpoint = Action('CreateDevEndpoint')
CreateJob = Action('CreateJob')
CreateMLTransform = Action('CreateMLTransform')
CreatePartition = Action('CreatePartition')
CreateScript = Action('CreateScript')
CreateSecurityConfiguration = Action('CreateSecurityConfiguration')
CreateTable = Action('CreateTable')
CreateTrigger = Action('CreateTrigger')
CreateUserDefinedFunction = Action('CreateUserDefinedFunction')
CreateWorkflow = Action('CreateWorkflow')
DeleteClassifier = Action('DeleteClassifier')
DeleteConnection = Action('DeleteConnection')
DeleteCrawler = Action('DeleteCrawler')
DeleteDatabase = Action('DeleteDatabase')
DeleteDevEndpoint = Action('DeleteDevEndpoint')
DeleteJob = Action('DeleteJob')
DeleteMLTransform = Action('DeleteMLTransform')
DeletePartition = Action('DeletePartition')
DeleteResourcePolicy = Action('DeleteResourcePolicy')
DeleteSecurityConfiguration = Action('DeleteSecurityConfiguration')
DeleteTable = Action('DeleteTable')
DeleteTableVersion = Action('DeleteTableVersion')
DeleteTrigger = Action('DeleteTrigger')
DeleteUserDefinedFunction = Action('DeleteUserDefinedFunction')
DeleteWorkflow = Action('DeleteWorkflow')
GetCatalogImportStatus = Action('GetCatalogImportStatus')
GetClassifier = Action('GetClassifier')
GetClassifiers = Action('GetClassifiers')
GetConnection = Action('GetConnection')
GetConnections = Action('GetConnections')
GetCrawler = Action('GetCrawler')
GetCrawlerMetrics = Action('GetCrawlerMetrics')
GetCrawlers = Action('GetCrawlers')
GetDataCatalogEncryptionSettings = \
    Action('GetDataCatalogEncryptionSettings')
GetDatabase = Action('GetDatabase')
GetDatabases = Action('GetDatabases')
GetDataflowGraph = Action('GetDataflowGraph')
GetDevEndpoint = Action('GetDevEndpoint')
GetDevEndpoints = Action('GetDevEndpoints')
GetJob = Action('GetJob')
GetJobBookmark = Action('GetJobBookmark')
GetJobRun = Action('GetJobRun')
GetJobRuns = Action('GetJobRuns')
GetJobs = Action('GetJobs')
GetMLTaskRun = Action('GetMLTaskRun')
GetMLTaskRuns = Action('GetMLTaskRuns')
GetMLTransform = Action('GetMLTransform')
GetMLTransforms = Action('GetMLTransforms')
GetMapping = Action('GetMapping')
GetPartition = Action('GetPartition')
GetPartitions = Action('GetPartitions')
GetPlan = Action('GetPlan')
GetResourcePolicy = Action('GetResourcePolicy')
GetSecurityConfiguration = Action('GetSecurityConfiguration')
GetSecurityConfigurations = Action('GetSecurityConfigurations')
GetTable = Action('GetTable')
GetTableVersion = Action('GetTableVersion')
GetTableVersions = Action('GetTableVersions')
GetTables = Action('GetTables')
GetTags = Action('GetTags')
GetTrigger = Action('GetTrigger')
GetTriggers = Action('GetTriggers')
GetUserDefinedFunction = Action('GetUserDefinedFunction')
GetUserDefinedFunctions = Action('GetUserDefinedFunctions')
GetWorkflow = Action('GetWorkflow')
GetWorkflowRun = Action('GetWorkflowRun')
GetWorkflowRunProperties = Action('GetWorkflowRunProperties')
GetWorkflowRuns = Action('GetWorkflowRuns')
ImportCatalogToGlue = Action('ImportCatalogToGlue')
ListCrawlers = Action('ListCrawlers')
ListDevEndpoints = Action('ListDevEndpoints')
ListJobs = Action('ListJobs')
ListMLTransforms = Action('ListMLTransforms')
ListTriggers = Action('ListTriggers')
ListWorkflows = Action('ListWorkflows')
PutDataCatalogEncryptionSettings = \
    Action('PutDataCatalogEncryptionSettings')
PutResourcePolicy = Action('PutResourcePolicy')
PutWorkflowRunProperties = Action('PutWorkflowRunProperties')
ResetJobBookmark = Action('ResetJobBookmark')
SearchTables = Action('SearchTables')
StartCrawler = Action('StartCrawler')
StartCrawlerSchedule = Action('StartCrawlerSchedule')
StartExportLabelsTaskRun = Action('StartExportLabelsTaskRun')
StartImportLabelsTaskRun = Action('StartImportLabelsTaskRun')
StartJobRun = Action('StartJobRun')
StartMLEvaluationTaskRun = Action('StartMLEvaluationTaskRun')
StartMLLabelingSetGenerationTaskRun = \
    Action('StartMLLabelingSetGenerationTaskRun')
StartTrigger = Action('StartTrigger')
StartWorkflowRun = Action('StartWorkflowRun')
StopCrawler = Action('StopCrawler')
StopCrawlerSchedule = Action('StopCrawlerSchedule')
StopTrigger = Action('StopTrigger')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateClassifier = Action('UpdateClassifier')
UpdateConnection = Action('UpdateConnection')
UpdateCrawler = Action('UpdateCrawler')
UpdateCrawlerSchedule = Action('UpdateCrawlerSchedule')
UpdateDatabase = Action('UpdateDatabase')
UpdateDevEndpoint = Action('UpdateDevEndpoint')
UpdateJob = Action('UpdateJob')
UpdateMLTransform = Action('UpdateMLTransform')
UpdatePartition = Action('UpdatePartition')
UpdateTable = Action('UpdateTable')
UpdateTrigger = Action('UpdateTrigger')
UpdateUserDefinedFunction = Action('UpdateUserDefinedFunction')
UpdateWorkflow = Action('UpdateWorkflow')
UseMLTransforms = Action('UseMLTransforms')



import unittest

from awacs.helpers.trust import (
    get_default_assumerole_policy,
    get_application_autoscaling_assumerole_policy,
    get_lambda_edge_assumerole_policy,
    make_service_domain_name,
)


def get_policy_services(policy):
    statement = policy.properties['Statement'][0]
    principal = statement.properties['Principal']
    return principal.data['Service']


def get_policy_service(policy):
    return get_policy_services(policy)[0]


class TestTrustHelpers(unittest.TestCase):

    def test_make_service_domain_name(self):
        self.assertEqual(
            'ec2.amazonaws.com',
            make_service_domain_name('ec2')
        )
        self.assertEqual(
            'ec2.amazonaws.com.cn',
            make_service_domain_name('ec2', region='cn-north-1')
        )
        # proove function is future proof.
        self.assertEqual(
            'ec2.amazonaws.com',
            make_service_domain_name('ec2', region='us-east-15')
        )

    def test_get_default_assumerole_policy(self):
        default_policy = get_default_assumerole_policy('us-east-1')
        cn_policy = get_default_assumerole_policy('cn-north-1')

        self.assertEqual(get_policy_service(default_policy),
                         'ec2.amazonaws.com')
        self.assertEqual(get_policy_service(cn_policy),
                         'ec2.amazonaws.com.cn')

    def test_get_application_autoscaling_assumerole_policy(self):
        assumerole_policy = get_application_autoscaling_assumerole_policy()
        self.assertEqual(
            'application-autoscaling.amazonaws.com',
            get_policy_service(assumerole_policy)
        )

    def test_get_lambda_edge_assumerole_policy(self):
        assumerole_policy = get_lambda_edge_assumerole_policy()
        services = get_policy_services(assumerole_policy)
        self.assertEqual(
            services,
            ('lambda.amazonaws.com', 'edgelambda.amazonaws.com'),
        )


if __name__ == '__main__':
    unittest.main()



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Secrets Manager'
prefix = 'secretsmanager'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelRotateSecret = Action('CancelRotateSecret')
CreateSecret = Action('CreateSecret')
DeleteResourcePolicy = Action('DeleteResourcePolicy')
DeleteSecret = Action('DeleteSecret')
DescribeSecret = Action('DescribeSecret')
GetRandomPassword = Action('GetRandomPassword')
GetResourcePolicy = Action('GetResourcePolicy')
GetSecretValue = Action('GetSecretValue')
ListSecretVersionIds = Action('ListSecretVersionIds')
ListSecrets = Action('ListSecrets')
PutResourcePolicy = Action('PutResourcePolicy')
PutSecretValue = Action('PutSecretValue')
RestoreSecret = Action('RestoreSecret')
RotateSecret = Action('RotateSecret')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateSecret = Action('UpdateSecret')
UpdateSecretVersionStage = Action('UpdateSecretVersionStage')
ValidateResourcePolicy = Action('ValidateResourcePolicy')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS IoT SiteWise'
prefix = 'iotsitewise'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateAssets = Action('AssociateAssets')
AssociateGatewaySink = Action('AssociateGatewaySink')
AssociateGatewaySource = Action('AssociateGatewaySource')
AssociateViewEntities = Action('AssociateViewEntities')
BatchAssociateProjectAssets = Action('BatchAssociateProjectAssets')
BatchDisassociateProjectAssets = Action('BatchDisassociateProjectAssets')
BatchPutAssetPropertyValue = Action('BatchPutAssetPropertyValue')
CreateAccessPolicy = Action('CreateAccessPolicy')
CreateAsset = Action('CreateAsset')
CreateAssetModel = Action('CreateAssetModel')
CreateAssetTemplate = Action('CreateAssetTemplate')
CreateDashboard = Action('CreateDashboard')
CreateGateway = Action('CreateGateway')
CreateGroup = Action('CreateGroup')
CreateMeasurementDataStore = Action('CreateMeasurementDataStore')
CreateMetricType = Action('CreateMetricType')
CreatePortal = Action('CreatePortal')
CreateProject = Action('CreateProject')
CreateView = Action('CreateView')
DeleteAccessPolicy = Action('DeleteAccessPolicy')
DeleteAsset = Action('DeleteAsset')
DeleteAssetModel = Action('DeleteAssetModel')
DeleteAssetTemplate = Action('DeleteAssetTemplate')
DeleteDashboard = Action('DeleteDashboard')
DeleteGateway = Action('DeleteGateway')
DeleteGroup = Action('DeleteGroup')
DeleteMeasurementDataStore = Action('DeleteMeasurementDataStore')
DeleteMetricType = Action('DeleteMetricType')
DeletePortal = Action('DeletePortal')
DeleteProject = Action('DeleteProject')
DeleteView = Action('DeleteView')
DeregisterViewEntities = Action('DeregisterViewEntities')
DescribeAccessPolicy = Action('DescribeAccessPolicy')
DescribeAsset = Action('DescribeAsset')
DescribeAssetModel = Action('DescribeAssetModel')
DescribeAssetProperty = Action('DescribeAssetProperty')
DescribeAssetTemplates = Action('DescribeAssetTemplates')
DescribeAssets = Action('DescribeAssets')
DescribeDashboard = Action('DescribeDashboard')
DescribeGateway = Action('DescribeGateway')
DescribeGatewayCapabilityConfiguration = \
    Action('DescribeGatewayCapabilityConfiguration')
DescribeGateways = Action('DescribeGateways')
DescribeGroups = Action('DescribeGroups')
DescribeLoggingOptions = Action('DescribeLoggingOptions')
DescribeMeasurementDataStores = Action('DescribeMeasurementDataStores')
DescribeMetricTypes = Action('DescribeMetricTypes')
DescribePortal = Action('DescribePortal')
DescribeProject = Action('DescribeProject')
DescribeViews = Action('DescribeViews')
DisassociateAssets = Action('DisassociateAssets')
DisassociateGatewaySink = Action('DisassociateGatewaySink')
DisassociateGatewaySource = Action('DisassociateGatewaySource')
DisassociateViewEntities = Action('DisassociateViewEntities')
GetAssetPropertyAggregates = Action('GetAssetPropertyAggregates')
GetAssetPropertyValue = Action('GetAssetPropertyValue')
GetAssetPropertyValueHistory = Action('GetAssetPropertyValueHistory')
GetMeasurementData = Action('GetMeasurementData')
GetMetricData = Action('GetMetricData')
ListAccessPolicies = Action('ListAccessPolicies')
ListAssetModels = Action('ListAssetModels')
ListAssetTemplates = Action('ListAssetTemplates')
ListAssets = Action('ListAssets')
ListAssociatedAssets = Action('ListAssociatedAssets')
ListDashboards = Action('ListDashboards')
ListGateways = Action('ListGateways')
ListGroups = Action('ListGroups')
ListMeasurementDataStores = Action('ListMeasurementDataStores')
ListMeasurementDataStreams = Action('ListMeasurementDataStreams')
ListMetricTypes = Action('ListMetricTypes')
ListPortals = Action('ListPortals')
ListProjectAssets = Action('ListProjectAssets')
ListProjects = Action('ListProjects')
ListTagsForResource = Action('ListTagsForResource')
ListViewEntities = Action('ListViewEntities')
ListViews = Action('ListViews')
PutLoggingOptions = Action('PutLoggingOptions')
RegisterViewEntities = Action('RegisterViewEntities')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateAccessPolicy = Action('UpdateAccessPolicy')
UpdateAsset = Action('UpdateAsset')
UpdateAssetModel = Action('UpdateAssetModel')
UpdateAssetProperty = Action('UpdateAssetProperty')
UpdateAssetTemplate = Action('UpdateAssetTemplate')
UpdateDashboard = Action('UpdateDashboard')
UpdateGateway = Action('UpdateGateway')
UpdateGatewayCapabilityConfiguration = \
    Action('UpdateGatewayCapabilityConfiguration')
UpdateGroup = Action('UpdateGroup')
UpdateMeasurementDataStore = Action('UpdateMeasurementDataStore')
UpdatePortal = Action('UpdatePortal')
UpdateProject = Action('UpdateProject')
UpdateView = Action('UpdateView')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon MQ'
prefix = 'mq'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateBroker = Action('CreateBroker')
CreateConfiguration = Action('CreateConfiguration')
CreateTags = Action('CreateTags')
CreateUser = Action('CreateUser')
DeleteBroker = Action('DeleteBroker')
DeleteTags = Action('DeleteTags')
DeleteUser = Action('DeleteUser')
DescribeBroker = Action('DescribeBroker')
DescribeBrokerEngineTypes = Action('DescribeBrokerEngineTypes')
DescribeBrokerInstanceOptions = Action('DescribeBrokerInstanceOptions')
DescribeConfiguration = Action('DescribeConfiguration')
DescribeConfigurationRevision = Action('DescribeConfigurationRevision')
DescribeUser = Action('DescribeUser')
ListBrokers = Action('ListBrokers')
ListConfigurationRevisions = Action('ListConfigurationRevisions')
ListConfigurations = Action('ListConfigurations')
ListTags = Action('ListTags')
ListUsers = Action('ListUsers')
RebootBroker = Action('RebootBroker')
UpdateBroker = Action('UpdateBroker')
UpdateConfiguration = Action('UpdateConfiguration')
UpdateUser = Action('UpdateUser')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Elemental MediaStore'
prefix = 'mediastore'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateContainer = Action('CreateContainer')
DeleteContainer = Action('DeleteContainer')
DeleteContainerPolicy = Action('DeleteContainerPolicy')
DeleteCorsPolicy = Action('DeleteCorsPolicy')
DeleteLifecyclePolicy = Action('DeleteLifecyclePolicy')
DeleteMetricPolicy = Action('DeleteMetricPolicy')
DeleteObject = Action('DeleteObject')
DescribeContainer = Action('DescribeContainer')
DescribeObject = Action('DescribeObject')
GetContainerPolicy = Action('GetContainerPolicy')
GetCorsPolicy = Action('GetCorsPolicy')
GetLifecyclePolicy = Action('GetLifecyclePolicy')
GetMetricPolicy = Action('GetMetricPolicy')
GetObject = Action('GetObject')
ListContainers = Action('ListContainers')
ListItems = Action('ListItems')
ListTagsForResource = Action('ListTagsForResource')
PutContainerPolicy = Action('PutContainerPolicy')
PutCorsPolicy = Action('PutCorsPolicy')
PutLifecyclePolicy = Action('PutLifecyclePolicy')
PutMetricPolicy = Action('PutMetricPolicy')
PutObject = Action('PutObject')
StartAccessLogging = Action('StartAccessLogging')
StopAccessLogging = Action('StopAccessLogging')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS License Manager'
prefix = 'license-manager'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateLicenseConfiguration = Action('CreateLicenseConfiguration')
DeleteLicenseConfiguration = Action('DeleteLicenseConfiguration')
GetLicenseConfiguration = Action('GetLicenseConfiguration')
GetServiceSettings = Action('GetServiceSettings')
ListAssociationsForLicenseConfiguration = \
    Action('ListAssociationsForLicenseConfiguration')
ListLicenseConfigurations = Action('ListLicenseConfigurations')
ListLicenseSpecificationsForResource = \
    Action('ListLicenseSpecificationsForResource')
ListResourceInventory = Action('ListResourceInventory')
ListTagsForResource = Action('ListTagsForResource')
ListUsageForLicenseConfiguration = \
    Action('ListUsageForLicenseConfiguration')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateLicenseConfiguration = Action('UpdateLicenseConfiguration')
UpdateLicenseSpecificationsForResource = \
    Action('UpdateLicenseSpecificationsForResource')
UpdateServiceSettings = Action('UpdateServiceSettings')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Lambda'
prefix = 'lambda'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddLayerVersionPermission = Action('AddLayerVersionPermission')
AddPermission = Action('AddPermission')
CreateAlias = Action('CreateAlias')
CreateEventSourceMapping = Action('CreateEventSourceMapping')
CreateFunction = Action('CreateFunction')
DeleteAlias = Action('DeleteAlias')
DeleteEventSourceMapping = Action('DeleteEventSourceMapping')
DeleteFunction = Action('DeleteFunction')
DeleteFunctionConcurrency = Action('DeleteFunctionConcurrency')
DeleteFunctionEventInvokeConfig = \
    Action('DeleteFunctionEventInvokeConfig')
DeleteLayerVersion = Action('DeleteLayerVersion')
DeleteProvisionedConcurrencyConfig = \
    Action('DeleteProvisionedConcurrencyConfig')
DisableReplication = Action('DisableReplication')
EnableReplication = Action('EnableReplication')
GetAccountSettings = Action('GetAccountSettings')
GetAlias = Action('GetAlias')
GetEventSourceMapping = Action('GetEventSourceMapping')
GetFunction = Action('GetFunction')
GetFunctionConcurrency = Action('GetFunctionConcurrency')
GetFunctionConfiguration = Action('GetFunctionConfiguration')
GetFunctionEventInvokeConfig = Action('GetFunctionEventInvokeConfig')
GetLayerVersion = Action('GetLayerVersion')
GetLayerVersionByArn = Action('GetLayerVersionByArn')
GetLayerVersionPolicy = Action('GetLayerVersionPolicy')
GetPolicy = Action('GetPolicy')
GetProvisionedConcurrencyConfig = \
    Action('GetProvisionedConcurrencyConfig')
InvokeAsync = Action('InvokeAsync')
InvokeFunction = Action('InvokeFunction')
ListAliases = Action('ListAliases')
ListEventSourceMappings = Action('ListEventSourceMappings')
ListFunctionEventInvokeConfigs = Action('ListFunctionEventInvokeConfigs')
ListFunctions = Action('ListFunctions')
ListLayerVersions = Action('ListLayerVersions')
ListLayers = Action('ListLayers')
ListProvisionedConcurrencyConfigs = \
    Action('ListProvisionedConcurrencyConfigs')
ListTags = Action('ListTags')
ListVersionsByFunction = Action('ListVersionsByFunction')
PublishLayerVersion = Action('PublishLayerVersion')
PublishVersion = Action('PublishVersion')
PutFunctionConcurrency = Action('PutFunctionConcurrency')
PutFunctionEventInvokeConfig = Action('PutFunctionEventInvokeConfig')
PutProvisionedConcurrencyConfig = \
    Action('PutProvisionedConcurrencyConfig')
RemoveLayerVersionPermission = Action('RemoveLayerVersionPermission')
RemovePermission = Action('RemovePermission')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateAlias = Action('UpdateAlias')
UpdateEventSourceMapping = Action('UpdateEventSourceMapping')
UpdateFunctionCode = Action('UpdateFunctionCode')
UpdateFunctionConfiguration = Action('UpdateFunctionConfiguration')
UpdateFunctionEventInvokeConfig = \
    Action('UpdateFunctionEventInvokeConfig')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CodeDeploy'
prefix = 'codedeploy'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTagsToOnPremisesInstances = Action('AddTagsToOnPremisesInstances')
BatchGetApplicationRevisions = Action('BatchGetApplicationRevisions')
BatchGetApplications = Action('BatchGetApplications')
BatchGetDeploymentGroups = Action('BatchGetDeploymentGroups')
BatchGetDeploymentInstances = Action('BatchGetDeploymentInstances')
BatchGetDeploymentTargets = Action('BatchGetDeploymentTargets')
BatchGetDeployments = Action('BatchGetDeployments')
BatchGetOnPremisesInstances = Action('BatchGetOnPremisesInstances')
ContinueDeployment = Action('ContinueDeployment')
CreateApplication = Action('CreateApplication')
CreateCloudFormationDeployment = Action('CreateCloudFormationDeployment')
CreateDeployment = Action('CreateDeployment')
CreateDeploymentConfig = Action('CreateDeploymentConfig')
CreateDeploymentGroup = Action('CreateDeploymentGroup')
DeleteApplication = Action('DeleteApplication')
DeleteDeploymentConfig = Action('DeleteDeploymentConfig')
DeleteDeploymentGroup = Action('DeleteDeploymentGroup')
DeleteGitHubAccountToken = Action('DeleteGitHubAccountToken')
DeleteResourcesByExternalId = Action('DeleteResourcesByExternalId')
DeregisterOnPremisesInstance = Action('DeregisterOnPremisesInstance')
GetApplication = Action('GetApplication')
GetApplicationRevision = Action('GetApplicationRevision')
GetDeployment = Action('GetDeployment')
GetDeploymentConfig = Action('GetDeploymentConfig')
GetDeploymentGroup = Action('GetDeploymentGroup')
GetDeploymentInstance = Action('GetDeploymentInstance')
GetDeploymentTarget = Action('GetDeploymentTarget')
GetOnPremisesInstance = Action('GetOnPremisesInstance')
ListApplicationRevisions = Action('ListApplicationRevisions')
ListApplications = Action('ListApplications')
ListDeploymentConfigs = Action('ListDeploymentConfigs')
ListDeploymentGroups = Action('ListDeploymentGroups')
ListDeploymentInstances = Action('ListDeploymentInstances')
ListDeploymentTargets = Action('ListDeploymentTargets')
ListDeployments = Action('ListDeployments')
ListGitHubAccountTokenNames = Action('ListGitHubAccountTokenNames')
ListOnPremisesInstances = Action('ListOnPremisesInstances')
ListTagsForResource = Action('ListTagsForResource')
PutLifecycleEventHookExecutionStatus = \
    Action('PutLifecycleEventHookExecutionStatus')
RegisterApplicationRevision = Action('RegisterApplicationRevision')
RegisterOnPremisesInstance = Action('RegisterOnPremisesInstance')
RemoveTagsFromOnPremisesInstances = \
    Action('RemoveTagsFromOnPremisesInstances')
SkipWaitTimeForInstanceTermination = \
    Action('SkipWaitTimeForInstanceTermination')
StopDeployment = Action('StopDeployment')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateApplication = Action('UpdateApplication')
UpdateDeploymentGroup = Action('UpdateDeploymentGroup')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Greengrass'
prefix = 'greengrass'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateRoleToGroup = Action('AssociateRoleToGroup')
AssociateServiceRoleToAccount = Action('AssociateServiceRoleToAccount')
CreateConnectorDefinition = Action('CreateConnectorDefinition')
CreateConnectorDefinitionVersion = \
    Action('CreateConnectorDefinitionVersion')
CreateCoreDefinition = Action('CreateCoreDefinition')
CreateCoreDefinitionVersion = Action('CreateCoreDefinitionVersion')
CreateDeployment = Action('CreateDeployment')
CreateDeviceDefinition = Action('CreateDeviceDefinition')
CreateDeviceDefinitionVersion = Action('CreateDeviceDefinitionVersion')
CreateFunctionDefinition = Action('CreateFunctionDefinition')
CreateFunctionDefinitionVersion = \
    Action('CreateFunctionDefinitionVersion')
CreateGroup = Action('CreateGroup')
CreateGroupCertificateAuthority = \
    Action('CreateGroupCertificateAuthority')
CreateGroupVersion = Action('CreateGroupVersion')
CreateLoggerDefinition = Action('CreateLoggerDefinition')
CreateLoggerDefinitionVersion = Action('CreateLoggerDefinitionVersion')
CreateResourceDefinition = Action('CreateResourceDefinition')
CreateResourceDefinitionVersion = \
    Action('CreateResourceDefinitionVersion')
CreateSoftwareUpdateJob = Action('CreateSoftwareUpdateJob')
CreateSubscriptionDefinition = Action('CreateSubscriptionDefinition')
CreateSubscriptionDefinitionVersion = \
    Action('CreateSubscriptionDefinitionVersion')
DeleteConnectorDefinition = Action('DeleteConnectorDefinition')
DeleteCoreDefinition = Action('DeleteCoreDefinition')
DeleteDeviceDefinition = Action('DeleteDeviceDefinition')
DeleteFunctionDefinition = Action('DeleteFunctionDefinition')
DeleteGroup = Action('DeleteGroup')
DeleteLoggerDefinition = Action('DeleteLoggerDefinition')
DeleteResourceDefinition = Action('DeleteResourceDefinition')
DeleteSubscriptionDefinition = Action('DeleteSubscriptionDefinition')
DisassociateRoleFromGroup = Action('DisassociateRoleFromGroup')
DisassociateServiceRoleFromAccount = \
    Action('DisassociateServiceRoleFromAccount')
Discover = Action('Discover')
GetAssociatedRole = Action('GetAssociatedRole')
GetBulkDeploymentStatus = Action('GetBulkDeploymentStatus')
GetConnectivityInfo = Action('GetConnectivityInfo')
GetConnectorDefinition = Action('GetConnectorDefinition')
GetConnectorDefinitionVersion = Action('GetConnectorDefinitionVersion')
GetCoreDefinition = Action('GetCoreDefinition')
GetCoreDefinitionVersion = Action('GetCoreDefinitionVersion')
GetDeploymentStatus = Action('GetDeploymentStatus')
GetDeviceDefinition = Action('GetDeviceDefinition')
GetDeviceDefinitionVersion = Action('GetDeviceDefinitionVersion')
GetFunctionDefinition = Action('GetFunctionDefinition')
GetFunctionDefinitionVersion = Action('GetFunctionDefinitionVersion')
GetGroup = Action('GetGroup')
GetGroupCertificateAuthority = Action('GetGroupCertificateAuthority')
GetGroupCertificateConfiguration = \
    Action('GetGroupCertificateConfiguration')
GetGroupVersion = Action('GetGroupVersion')
GetLoggerDefinition = Action('GetLoggerDefinition')
GetLoggerDefinitionVersion = Action('GetLoggerDefinitionVersion')
GetResourceDefinition = Action('GetResourceDefinition')
GetResourceDefinitionVersion = Action('GetResourceDefinitionVersion')
GetServiceRoleForAccount = Action('GetServiceRoleForAccount')
GetSubscriptionDefinition = Action('GetSubscriptionDefinition')
GetSubscriptionDefinitionVersion = \
    Action('GetSubscriptionDefinitionVersion')
ListBulkDeploymentDetailedReports = \
    Action('ListBulkDeploymentDetailedReports')
ListBulkDeployments = Action('ListBulkDeployments')
ListConnectorDefinitionVersions = \
    Action('ListConnectorDefinitionVersions')
ListConnectorDefinitions = Action('ListConnectorDefinitions')
ListCoreDefinitionVersions = Action('ListCoreDefinitionVersions')
ListCoreDefinitions = Action('ListCoreDefinitions')
ListDeployments = Action('ListDeployments')
ListDeviceDefinitionVersions = Action('ListDeviceDefinitionVersions')
ListDeviceDefinitions = Action('ListDeviceDefinitions')
ListFunctionDefinitionVersions = Action('ListFunctionDefinitionVersions')
ListFunctionDefinitions = Action('ListFunctionDefinitions')
ListGroupCertificateAuthorities = \
    Action('ListGroupCertificateAuthorities')
ListGroupVersions = Action('ListGroupVersions')
ListGroups = Action('ListGroups')
ListLoggerDefinitionVersions = Action('ListLoggerDefinitionVersions')
ListLoggerDefinitions = Action('ListLoggerDefinitions')
ListResourceDefinitionVersions = Action('ListResourceDefinitionVersions')
ListResourceDefinitions = Action('ListResourceDefinitions')
ListSubscriptionDefinitionVersions = \
    Action('ListSubscriptionDefinitionVersions')
ListSubscriptionDefinitions = Action('ListSubscriptionDefinitions')
ListTagsForResource = Action('ListTagsForResource')
ResetDeployments = Action('ResetDeployments')
StartBulkDeployment = Action('StartBulkDeployment')
StopBulkDeployment = Action('StopBulkDeployment')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateConnectivityInfo = Action('UpdateConnectivityInfo')
UpdateConnectorDefinition = Action('UpdateConnectorDefinition')
UpdateCoreDefinition = Action('UpdateCoreDefinition')
UpdateDeviceDefinition = Action('UpdateDeviceDefinition')
UpdateFunctionDefinition = Action('UpdateFunctionDefinition')
UpdateGroup = Action('UpdateGroup')
UpdateGroupCertificateConfiguration = \
    Action('UpdateGroupCertificateConfiguration')
UpdateLoggerDefinition = Action('UpdateLoggerDefinition')
UpdateResourceDefinition = Action('UpdateResourceDefinition')
UpdateSubscriptionDefinition = Action('UpdateSubscriptionDefinition')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Elastic File System'
prefix = 'elasticfilesystem'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


Backup = Action('Backup')
ClientMount = Action('ClientMount')
ClientRootAccess = Action('ClientRootAccess')
ClientWrite = Action('ClientWrite')
CreateAccessPoint = Action('CreateAccessPoint')
CreateFileSystem = Action('CreateFileSystem')
CreateMountTarget = Action('CreateMountTarget')
CreateTags = Action('CreateTags')
DeleteAccessPoint = Action('DeleteAccessPoint')
DeleteFileSystem = Action('DeleteFileSystem')
DeleteFileSystemPolicy = Action('DeleteFileSystemPolicy')
DeleteMountTarget = Action('DeleteMountTarget')
DeleteTags = Action('DeleteTags')
DescribeAccessPoints = Action('DescribeAccessPoints')
DescribeBackupPolicy = Action('DescribeBackupPolicy')
DescribeFileSystemPolicy = Action('DescribeFileSystemPolicy')
DescribeFileSystems = Action('DescribeFileSystems')
DescribeLifecycleConfiguration = Action('DescribeLifecycleConfiguration')
DescribeMountTargetSecurityGroups = \
    Action('DescribeMountTargetSecurityGroups')
DescribeMountTargets = Action('DescribeMountTargets')
DescribeTags = Action('DescribeTags')
ListTagsForResource = Action('ListTagsForResource')
ModifyMountTargetSecurityGroups = \
    Action('ModifyMountTargetSecurityGroups')
PutBackupPolicy = Action('PutBackupPolicy')
PutFileSystemPolicy = Action('PutFileSystemPolicy')
PutLifecycleConfiguration = Action('PutLifecycleConfiguration')
Restore = Action('Restore')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateFileSystem = Action('UpdateFileSystem')



import unittest

from awacs import s3, ec2, iam
from awacs.aws import PolicyDocument, Statement, Action, Condition
from awacs.aws import StringEquals, StringLike


class TestEquality(unittest.TestCase):
    def test_condition_equality(self):
        self.assertEqualWithHash(
            Condition(StringLike("s3:prefix", ["home/${aws:username}/*"])),
            Condition(StringLike("s3:prefix", ["home/${aws:username}/*"])))

        self.assertNotEqualWithHash(
            Condition(StringLike("s3:prefix", ["home/${aws:username}/*"])),
            Condition(StringLike("s3:prefix", ["other/${aws:username}/*"])))

        self.assertNotEqualWithHash(
            Condition(StringLike("s3:prefix", ["home/${aws:username}/*"])),
            Condition(StringEquals("s3:prefix", ["home/${aws:username}/*"])))

    def test_arn_equality(self):
        self.assertEqualWithHash(
            s3.ARN("myBucket"), s3.ARN("myBucket"))

        self.assertNotEqualWithHash(
            s3.ARN("myBucket"), s3.ARN("myOtherBucket"))

        self.assertEqualWithHash(
            ec2.ARN("some-resource", "some-region", "some-account"),
            ec2.ARN("some-resource", "some-region", "some-account"))

        self.assertNotEqualWithHash(
            ec2.ARN("some-resource", "some-region", "some-account"),
            ec2.ARN("some-resource", "some-other-region", "some-account"))

        self.assertNotEqualWithHash(
            ec2.ARN("some-resource", "some-region", "some-account"),
            iam.ARN("some-resource", "some-region", "some-account"))

    def test_action_equality(self):
        self.assertEqualWithHash(
            Action('autoscaling', 'DescribeLaunchConfigurations'),
            Action('autoscaling', 'DescribeLaunchConfigurations'))

        self.assertNotEqualWithHash(
            Action('autoscaling', 'DescribeLaunchConfigurations'),
            Action('ec2', 'DescribeInstances'))

    def test_statement_equality(self):
        one = Statement(
            Effect="Allow",
            Action=[
                Action('autoscaling', 'DescribeLaunchConfigurations'),
            ],
            Resource=["*"]
        )
        one_again = Statement(
            Effect="Allow",
            Action=[
                Action('autoscaling', 'DescribeLaunchConfigurations'),
            ],
            Resource=["*"]
        )
        two = Statement(
            Effect="Allow",
            Action=[
                Action('ec2', 'DescribeInstances'),
            ],
            Resource=["*"]
        )

        self.assertEqualWithHash(one, one_again)
        self.assertNotEqualWithHash(one, two)

    def test_policy_document_equality(self):
        one = PolicyDocument(
            Version="2012-10-17",
            Statement=[
                Statement(
                    Effect="Allow",
                    Action=[
                        Action('autoscaling', 'DescribeLaunchConfigurations'),
                    ],
                    Resource=["*"]
                )
            ]
        )
        one_again = PolicyDocument(
            Version="2012-10-17",
            Statement=[
                Statement(
                    Effect="Allow",
                    Action=[
                        Action('autoscaling', 'DescribeLaunchConfigurations'),
                    ],
                    Resource=["*"]
                )
            ]
        )

        two = PolicyDocument(
            Version="2012-10-17",
            Statement=[
                Statement(
                    Effect="Allow",
                    Action=[
                        Action('ec2', 'DescribeInstances'),
                    ],
                    Resource=["*"]
                )
            ]
        )
        self.assertEqualWithHash(one, one_again)
        self.assertNotEqualWithHash(one, two)

    def assertEqualWithHash(self, one, two):
        self.assertTrue(one == two)
        self.assertEqual(hash(one), hash(two))

    def assertNotEqualWithHash(self, one, two):
        self.assertTrue(one != two)
        self.assertNotEqual(hash(one), hash(two))



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CodeBuild'
prefix = 'codebuild'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchDeleteBuilds = Action('BatchDeleteBuilds')
BatchGetBuildBatches = Action('BatchGetBuildBatches')
BatchGetBuilds = Action('BatchGetBuilds')
BatchGetProjects = Action('BatchGetProjects')
BatchGetReportGroups = Action('BatchGetReportGroups')
BatchGetReports = Action('BatchGetReports')
BatchPutCodeCoverages = Action('BatchPutCodeCoverages')
BatchPutTestCases = Action('BatchPutTestCases')
CreateProject = Action('CreateProject')
CreateReport = Action('CreateReport')
CreateReportGroup = Action('CreateReportGroup')
CreateWebhook = Action('CreateWebhook')
DeleteBuildBatch = Action('DeleteBuildBatch')
DeleteOAuthToken = Action('DeleteOAuthToken')
DeleteProject = Action('DeleteProject')
DeleteReport = Action('DeleteReport')
DeleteReportGroup = Action('DeleteReportGroup')
DeleteResourcePolicy = Action('DeleteResourcePolicy')
DeleteSourceCredentials = Action('DeleteSourceCredentials')
DeleteWebhook = Action('DeleteWebhook')
DescribeCodeCoverages = Action('DescribeCodeCoverages')
DescribeTestCases = Action('DescribeTestCases')
GetResourcePolicy = Action('GetResourcePolicy')
ImportSourceCredentials = Action('ImportSourceCredentials')
InvalidateProjectCache = Action('InvalidateProjectCache')
ListBuildBatches = Action('ListBuildBatches')
ListBuildBatchesForProject = Action('ListBuildBatchesForProject')
ListBuilds = Action('ListBuilds')
ListBuildsForProject = Action('ListBuildsForProject')
ListConnectedOAuthAccounts = Action('ListConnectedOAuthAccounts')
ListCuratedEnvironmentImages = Action('ListCuratedEnvironmentImages')
ListProjects = Action('ListProjects')
ListReportGroups = Action('ListReportGroups')
ListReports = Action('ListReports')
ListReportsForReportGroup = Action('ListReportsForReportGroup')
ListRepositories = Action('ListRepositories')
ListSharedProjects = Action('ListSharedProjects')
ListSharedReportGroups = Action('ListSharedReportGroups')
ListSourceCredentials = Action('ListSourceCredentials')
PersistOAuthToken = Action('PersistOAuthToken')
PutResourcePolicy = Action('PutResourcePolicy')
RetryBuild = Action('RetryBuild')
RetryBuildBatch = Action('RetryBuildBatch')
StartBuild = Action('StartBuild')
StartBuildBatch = Action('StartBuildBatch')
StopBuild = Action('StopBuild')
StopBuildBatch = Action('StopBuildBatch')
UpdateProject = Action('UpdateProject')
UpdateReport = Action('UpdateReport')
UpdateReportGroup = Action('UpdateReportGroup')
UpdateWebhook = Action('UpdateWebhook')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Serverless Application Repository'
prefix = 'serverlessrepo'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateApplication = Action('CreateApplication')
CreateApplicationVersion = Action('CreateApplicationVersion')
CreateCloudFormationChangeSet = Action('CreateCloudFormationChangeSet')
CreateCloudFormationTemplate = Action('CreateCloudFormationTemplate')
DeleteApplication = Action('DeleteApplication')
GetApplication = Action('GetApplication')
GetApplicationPolicy = Action('GetApplicationPolicy')
GetCloudFormationTemplate = Action('GetCloudFormationTemplate')
ListApplicationDependencies = Action('ListApplicationDependencies')
ListApplicationVersions = Action('ListApplicationVersions')
ListApplications = Action('ListApplications')
PutApplicationPolicy = Action('PutApplicationPolicy')
SearchApplications = Action('SearchApplications')
UnshareApplication = Action('UnshareApplication')
UpdateApplication = Action('UpdateApplication')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CloudTrail'
prefix = 'cloudtrail'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTags = Action('AddTags')
CreateTrail = Action('CreateTrail')
DeleteTrail = Action('DeleteTrail')
DescribeTrails = Action('DescribeTrails')
GetEventSelectors = Action('GetEventSelectors')
GetInsightSelectors = Action('GetInsightSelectors')
GetTrail = Action('GetTrail')
GetTrailStatus = Action('GetTrailStatus')
ListPublicKeys = Action('ListPublicKeys')
ListTags = Action('ListTags')
ListTrails = Action('ListTrails')
LookupEvents = Action('LookupEvents')
PutEventSelectors = Action('PutEventSelectors')
PutInsightSelectors = Action('PutInsightSelectors')
RemoveTags = Action('RemoveTags')
StartLogging = Action('StartLogging')
StopLogging = Action('StopLogging')
UpdateTrail = Action('UpdateTrail')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Inspector'
prefix = 'inspector'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddAttributesToFindings = Action('AddAttributesToFindings')
CreateAssessmentTarget = Action('CreateAssessmentTarget')
CreateAssessmentTemplate = Action('CreateAssessmentTemplate')
CreateResourceGroup = Action('CreateResourceGroup')
DeleteAssessmentRun = Action('DeleteAssessmentRun')
DeleteAssessmentTarget = Action('DeleteAssessmentTarget')
DeleteAssessmentTemplate = Action('DeleteAssessmentTemplate')
DescribeAssessmentRuns = Action('DescribeAssessmentRuns')
DescribeAssessmentTargets = Action('DescribeAssessmentTargets')
DescribeAssessmentTemplates = Action('DescribeAssessmentTemplates')
DescribeCrossAccountAccessRole = Action('DescribeCrossAccountAccessRole')
DescribeFindings = Action('DescribeFindings')
DescribeResourceGroups = Action('DescribeResourceGroups')
DescribeRulesPackages = Action('DescribeRulesPackages')
GetTelemetryMetadata = Action('GetTelemetryMetadata')
ListAssessmentRunAgents = Action('ListAssessmentRunAgents')
ListAssessmentRuns = Action('ListAssessmentRuns')
ListAssessmentTargets = Action('ListAssessmentTargets')
ListAssessmentTemplates = Action('ListAssessmentTemplates')
ListEventSubscriptions = Action('ListEventSubscriptions')
ListFindings = Action('ListFindings')
ListRulesPackages = Action('ListRulesPackages')
ListTagsForResource = Action('ListTagsForResource')
PreviewAgents = Action('PreviewAgents')
RegisterCrossAccountAccessRole = Action('RegisterCrossAccountAccessRole')
RemoveAttributesFromFindings = Action('RemoveAttributesFromFindings')
SetTagsForResource = Action('SetTagsForResource')
StartAssessmentRun = Action('StartAssessmentRun')
StopAssessmentRun = Action('StopAssessmentRun')
SubscribeToEvent = Action('SubscribeToEvent')
UnsubscribeFromEvent = Action('UnsubscribeFromEvent')
UpdateAssessmentTarget = Action('UpdateAssessmentTarget')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Resource Access Manager'
prefix = 'ram'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptResourceShareInvitation = Action('AcceptResourceShareInvitation')
AssociateResourceShare = Action('AssociateResourceShare')
AssociateResourceSharePermission = \
    Action('AssociateResourceSharePermission')
CreateResourceShare = Action('CreateResourceShare')
DeleteResourceShare = Action('DeleteResourceShare')
DisassociateResourceShare = Action('DisassociateResourceShare')
DisassociateResourceSharePermission = \
    Action('DisassociateResourceSharePermission')
EnableSharingWithAwsOrganization = \
    Action('EnableSharingWithAwsOrganization')
GetPermission = Action('GetPermission')
GetResourcePolicies = Action('GetResourcePolicies')
GetResourceShareAssociations = Action('GetResourceShareAssociations')
GetResourceShareInvitations = Action('GetResourceShareInvitations')
GetResourceShares = Action('GetResourceShares')
ListPendingInvitationResources = Action('ListPendingInvitationResources')
ListPermissions = Action('ListPermissions')
ListPrincipals = Action('ListPrincipals')
ListResourceSharePermissions = Action('ListResourceSharePermissions')
ListResources = Action('ListResources')
RejectResourceShareInvitation = Action('RejectResourceShareInvitation')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateResourceShare = Action('UpdateResourceShare')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Data Pipeline'
prefix = 'datapipeline'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


ActivatePipeline = Action('ActivatePipeline')
AddTags = Action('AddTags')
CreatePipeline = Action('CreatePipeline')
DeactivatePipeline = Action('DeactivatePipeline')
DeletePipeline = Action('DeletePipeline')
DescribeObjects = Action('DescribeObjects')
DescribePipelines = Action('DescribePipelines')
EvaluateExpression = Action('EvaluateExpression')
GetAccountLimits = Action('GetAccountLimits')
GetPipelineDefinition = Action('GetPipelineDefinition')
ListPipelines = Action('ListPipelines')
PollForTask = Action('PollForTask')
PutAccountLimits = Action('PutAccountLimits')
PutPipelineDefinition = Action('PutPipelineDefinition')
QueryObjects = Action('QueryObjects')
RemoveTags = Action('RemoveTags')
ReportTaskProgress = Action('ReportTaskProgress')
ReportTaskRunnerHeartbeat = Action('ReportTaskRunnerHeartbeat')
SetStatus = Action('SetStatus')
SetTaskStatus = Action('SetTaskStatus')
ValidatePipelineDefinition = Action('ValidatePipelineDefinition')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Organizations'
prefix = 'organizations'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptHandshake = Action('AcceptHandshake')
AttachPolicy = Action('AttachPolicy')
CancelHandshake = Action('CancelHandshake')
CreateAccount = Action('CreateAccount')
CreateGovCloudAccount = Action('CreateGovCloudAccount')
CreateOrganization = Action('CreateOrganization')
CreateOrganizationalUnit = Action('CreateOrganizationalUnit')
CreatePolicy = Action('CreatePolicy')
DeclineHandshake = Action('DeclineHandshake')
DeleteOrganization = Action('DeleteOrganization')
DeleteOrganizationalUnit = Action('DeleteOrganizationalUnit')
DeletePolicy = Action('DeletePolicy')
DeregisterDelegatedAdministrator = \
    Action('DeregisterDelegatedAdministrator')
DescribeAccount = Action('DescribeAccount')
DescribeCreateAccountStatus = Action('DescribeCreateAccountStatus')
DescribeEffectivePolicy = Action('DescribeEffectivePolicy')
DescribeHandshake = Action('DescribeHandshake')
DescribeOrganization = Action('DescribeOrganization')
DescribeOrganizationalUnit = Action('DescribeOrganizationalUnit')
DescribePolicy = Action('DescribePolicy')
DetachPolicy = Action('DetachPolicy')
DisableAWSServiceAccess = Action('DisableAWSServiceAccess')
DisablePolicyType = Action('DisablePolicyType')
EnableAWSServiceAccess = Action('EnableAWSServiceAccess')
EnableAllFeatures = Action('EnableAllFeatures')
EnablePolicyType = Action('EnablePolicyType')
InviteAccountToOrganization = Action('InviteAccountToOrganization')
LeaveOrganization = Action('LeaveOrganization')
ListAWSServiceAccessForOrganization = \
    Action('ListAWSServiceAccessForOrganization')
ListAccounts = Action('ListAccounts')
ListAccountsForParent = Action('ListAccountsForParent')
ListChildren = Action('ListChildren')
ListCreateAccountStatus = Action('ListCreateAccountStatus')
ListDelegatedAdministrators = Action('ListDelegatedAdministrators')
ListDelegatedServicesForAccount = \
    Action('ListDelegatedServicesForAccount')
ListHandshakesForAccount = Action('ListHandshakesForAccount')
ListHandshakesForOrganization = Action('ListHandshakesForOrganization')
ListOrganizationalUnitsForParent = \
    Action('ListOrganizationalUnitsForParent')
ListParents = Action('ListParents')
ListPolicies = Action('ListPolicies')
ListPoliciesForTarget = Action('ListPoliciesForTarget')
ListRoots = Action('ListRoots')
ListTagsForResource = Action('ListTagsForResource')
ListTargetsForPolicy = Action('ListTargetsForPolicy')
MoveAccount = Action('MoveAccount')
RegisterDelegatedAdministrator = Action('RegisterDelegatedAdministrator')
RemoveAccountFromOrganization = Action('RemoveAccountFromOrganization')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateOrganizationalUnit = Action('UpdateOrganizationalUnit')
UpdatePolicy = Action('UpdatePolicy')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon SES'
prefix = 'ses'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CloneReceiptRuleSet = Action('CloneReceiptRuleSet')
CreateConfigurationSet = Action('CreateConfigurationSet')
CreateConfigurationSetEventDestination = \
    Action('CreateConfigurationSetEventDestination')
CreateConfigurationSetTrackingOptions = \
    Action('CreateConfigurationSetTrackingOptions')
CreateCustomVerificationEmailTemplate = \
    Action('CreateCustomVerificationEmailTemplate')
CreateReceiptFilter = Action('CreateReceiptFilter')
CreateReceiptRule = Action('CreateReceiptRule')
CreateReceiptRuleSet = Action('CreateReceiptRuleSet')
CreateTemplate = Action('CreateTemplate')
DeleteConfigurationSet = Action('DeleteConfigurationSet')
DeleteConfigurationSetEventDestination = \
    Action('DeleteConfigurationSetEventDestination')
DeleteConfigurationSetTrackingOptions = \
    Action('DeleteConfigurationSetTrackingOptions')
DeleteCustomVerificationEmailTemplate = \
    Action('DeleteCustomVerificationEmailTemplate')
DeleteIdentity = Action('DeleteIdentity')
DeleteIdentityPolicy = Action('DeleteIdentityPolicy')
DeleteReceiptFilter = Action('DeleteReceiptFilter')
DeleteReceiptRule = Action('DeleteReceiptRule')
DeleteReceiptRuleSet = Action('DeleteReceiptRuleSet')
DeleteTemplate = Action('DeleteTemplate')
DeleteVerifiedEmailAddress = Action('DeleteVerifiedEmailAddress')
DescribeActiveReceiptRuleSet = Action('DescribeActiveReceiptRuleSet')
DescribeConfigurationSet = Action('DescribeConfigurationSet')
DescribeReceiptRule = Action('DescribeReceiptRule')
DescribeReceiptRuleSet = Action('DescribeReceiptRuleSet')
GetAccountSendingEnabled = Action('GetAccountSendingEnabled')
GetCustomVerificationEmailTemplate = \
    Action('GetCustomVerificationEmailTemplate')
GetIdentityDkimAttributes = Action('GetIdentityDkimAttributes')
GetIdentityMailFromDomainAttributes = \
    Action('GetIdentityMailFromDomainAttributes')
GetIdentityNotificationAttributes = \
    Action('GetIdentityNotificationAttributes')
GetIdentityPolicies = Action('GetIdentityPolicies')
GetIdentityVerificationAttributes = \
    Action('GetIdentityVerificationAttributes')
GetSendQuota = Action('GetSendQuota')
GetSendStatistics = Action('GetSendStatistics')
GetTemplate = Action('GetTemplate')
ListConfigurationSets = Action('ListConfigurationSets')
ListCustomVerificationEmailTemplates = \
    Action('ListCustomVerificationEmailTemplates')
ListIdentities = Action('ListIdentities')
ListIdentityPolicies = Action('ListIdentityPolicies')
ListReceiptFilters = Action('ListReceiptFilters')
ListReceiptRuleSets = Action('ListReceiptRuleSets')
ListTemplates = Action('ListTemplates')
ListVerifiedEmailAddresses = Action('ListVerifiedEmailAddresses')
PutIdentityPolicy = Action('PutIdentityPolicy')
ReorderReceiptRuleSet = Action('ReorderReceiptRuleSet')
SendBounce = Action('SendBounce')
SendBulkTemplatedEmail = Action('SendBulkTemplatedEmail')
SendCustomVerificationEmail = Action('SendCustomVerificationEmail')
SendEmail = Action('SendEmail')
SendRawEmail = Action('SendRawEmail')
SendTemplatedEmail = Action('SendTemplatedEmail')
SetActiveReceiptRuleSet = Action('SetActiveReceiptRuleSet')
SetIdentityDkimEnabled = Action('SetIdentityDkimEnabled')
SetIdentityFeedbackForwardingEnabled = \
    Action('SetIdentityFeedbackForwardingEnabled')
SetIdentityHeadersInNotificationsEnabled = \
    Action('SetIdentityHeadersInNotificationsEnabled')
SetIdentityMailFromDomain = Action('SetIdentityMailFromDomain')
SetIdentityNotificationTopic = Action('SetIdentityNotificationTopic')
SetReceiptRulePosition = Action('SetReceiptRulePosition')
TestRenderTemplate = Action('TestRenderTemplate')
UpdateAccountSendingEnabled = Action('UpdateAccountSendingEnabled')
UpdateConfigurationSetEventDestination = \
    Action('UpdateConfigurationSetEventDestination')
UpdateConfigurationSetReputationMetricsEnabled = \
    Action('UpdateConfigurationSetReputationMetricsEnabled')
UpdateConfigurationSetSendingEnabled = \
    Action('UpdateConfigurationSetSendingEnabled')
UpdateConfigurationSetTrackingOptions = \
    Action('UpdateConfigurationSetTrackingOptions')
UpdateCustomVerificationEmailTemplate = \
    Action('UpdateCustomVerificationEmailTemplate')
UpdateReceiptRule = Action('UpdateReceiptRule')
UpdateTemplate = Action('UpdateTemplate')
VerifyDomainDkim = Action('VerifyDomainDkim')
VerifyDomainIdentity = Action('VerifyDomainIdentity')
VerifyEmailAddress = Action('VerifyEmailAddress')
VerifyEmailIdentity = Action('VerifyEmailIdentity')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Device Farm'
prefix = 'devicefarm'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateDevicePool = Action('CreateDevicePool')
CreateInstanceProfile = Action('CreateInstanceProfile')
CreateNetworkProfile = Action('CreateNetworkProfile')
CreateProject = Action('CreateProject')
CreateRemoteAccessSession = Action('CreateRemoteAccessSession')
CreateTestGridProject = Action('CreateTestGridProject')
CreateTestGridUrl = Action('CreateTestGridUrl')
CreateUpload = Action('CreateUpload')
CreateVPCEConfiguration = Action('CreateVPCEConfiguration')
DeleteDevicePool = Action('DeleteDevicePool')
DeleteInstanceProfile = Action('DeleteInstanceProfile')
DeleteNetworkProfile = Action('DeleteNetworkProfile')
DeleteProject = Action('DeleteProject')
DeleteRemoteAccessSession = Action('DeleteRemoteAccessSession')
DeleteRun = Action('DeleteRun')
DeleteTestGridProject = Action('DeleteTestGridProject')
DeleteUpload = Action('DeleteUpload')
DeleteVPCEConfiguration = Action('DeleteVPCEConfiguration')
GetAccountSettings = Action('GetAccountSettings')
GetDevice = Action('GetDevice')
GetDeviceInstance = Action('GetDeviceInstance')
GetDevicePool = Action('GetDevicePool')
GetDevicePoolCompatibility = Action('GetDevicePoolCompatibility')
GetInstanceProfile = Action('GetInstanceProfile')
GetJob = Action('GetJob')
GetNetworkProfile = Action('GetNetworkProfile')
GetOfferingStatus = Action('GetOfferingStatus')
GetProject = Action('GetProject')
GetRemoteAccessSession = Action('GetRemoteAccessSession')
GetRun = Action('GetRun')
GetSuite = Action('GetSuite')
GetTest = Action('GetTest')
GetTestGridProject = Action('GetTestGridProject')
GetTestGridSession = Action('GetTestGridSession')
GetUpload = Action('GetUpload')
GetVPCEConfiguration = Action('GetVPCEConfiguration')
InstallToRemoteAccessSession = Action('InstallToRemoteAccessSession')
ListArtifacts = Action('ListArtifacts')
ListDeviceInstances = Action('ListDeviceInstances')
ListDevicePools = Action('ListDevicePools')
ListDevices = Action('ListDevices')
ListInstanceProfiles = Action('ListInstanceProfiles')
ListJobs = Action('ListJobs')
ListNetworkProfiles = Action('ListNetworkProfiles')
ListOfferingPromotions = Action('ListOfferingPromotions')
ListOfferingTransactions = Action('ListOfferingTransactions')
ListOfferings = Action('ListOfferings')
ListProjects = Action('ListProjects')
ListRemoteAccessSessions = Action('ListRemoteAccessSessions')
ListRuns = Action('ListRuns')
ListSamples = Action('ListSamples')
ListSuites = Action('ListSuites')
ListTagsForResource = Action('ListTagsForResource')
ListTestGridProjects = Action('ListTestGridProjects')
ListTestGridSessionActions = Action('ListTestGridSessionActions')
ListTestGridSessionArtifacts = Action('ListTestGridSessionArtifacts')
ListTestGridSessions = Action('ListTestGridSessions')
ListTests = Action('ListTests')
ListUniqueProblems = Action('ListUniqueProblems')
ListUploads = Action('ListUploads')
ListVPCEConfigurations = Action('ListVPCEConfigurations')
PurchaseOffering = Action('PurchaseOffering')
RenewOffering = Action('RenewOffering')
ScheduleRun = Action('ScheduleRun')
StopJob = Action('StopJob')
StopRemoteAccessSession = Action('StopRemoteAccessSession')
StopRun = Action('StopRun')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDeviceInstance = Action('UpdateDeviceInstance')
UpdateDevicePool = Action('UpdateDevicePool')
UpdateInstanceProfile = Action('UpdateInstanceProfile')
UpdateNetworkProfile = Action('UpdateNetworkProfile')
UpdateProject = Action('UpdateProject')
UpdateTestGridProject = Action('UpdateTestGridProject')
UpdateUpload = Action('UpdateUpload')
UpdateVPCEConfiguration = Action('UpdateVPCEConfiguration')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Elastic Beanstalk'
prefix = 'elasticbeanstalk'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AbortEnvironmentUpdate = Action('AbortEnvironmentUpdate')
AddTags = Action('AddTags')
ApplyEnvironmentManagedAction = Action('ApplyEnvironmentManagedAction')
AssociateEnvironmentOperationsRole = \
    Action('AssociateEnvironmentOperationsRole')
CheckDNSAvailability = Action('CheckDNSAvailability')
ComposeEnvironments = Action('ComposeEnvironments')
CreateApplication = Action('CreateApplication')
CreateApplicationVersion = Action('CreateApplicationVersion')
CreateConfigurationTemplate = Action('CreateConfigurationTemplate')
CreateEnvironment = Action('CreateEnvironment')
CreatePlatformVersion = Action('CreatePlatformVersion')
CreateStorageLocation = Action('CreateStorageLocation')
DeleteApplication = Action('DeleteApplication')
DeleteApplicationVersion = Action('DeleteApplicationVersion')
DeleteConfigurationTemplate = Action('DeleteConfigurationTemplate')
DeleteEnvironmentConfiguration = Action('DeleteEnvironmentConfiguration')
DeletePlatformVersion = Action('DeletePlatformVersion')
DescribeAccountAttributes = Action('DescribeAccountAttributes')
DescribeApplicationVersions = Action('DescribeApplicationVersions')
DescribeApplications = Action('DescribeApplications')
DescribeConfigurationOptions = Action('DescribeConfigurationOptions')
DescribeConfigurationSettings = Action('DescribeConfigurationSettings')
DescribeEnvironmentHealth = Action('DescribeEnvironmentHealth')
DescribeEnvironmentManagedActionHistory = \
    Action('DescribeEnvironmentManagedActionHistory')
DescribeEnvironmentManagedActions = \
    Action('DescribeEnvironmentManagedActions')
DescribeEnvironmentResources = Action('DescribeEnvironmentResources')
DescribeEnvironments = Action('DescribeEnvironments')
DescribeEvents = Action('DescribeEvents')
DescribeInstancesHealth = Action('DescribeInstancesHealth')
DescribePlatformVersion = Action('DescribePlatformVersion')
DisassociateEnvironmentOperationsRole = \
    Action('DisassociateEnvironmentOperationsRole')
ListAvailableSolutionStacks = Action('ListAvailableSolutionStacks')
ListPlatformBranches = Action('ListPlatformBranches')
ListPlatformVersions = Action('ListPlatformVersions')
ListTagsForResource = Action('ListTagsForResource')
PutInstanceStatistics = Action('PutInstanceStatistics')
RebuildEnvironment = Action('RebuildEnvironment')
RemoveTags = Action('RemoveTags')
RequestEnvironmentInfo = Action('RequestEnvironmentInfo')
RestartAppServer = Action('RestartAppServer')
RetrieveEnvironmentInfo = Action('RetrieveEnvironmentInfo')
SwapEnvironmentCNAMEs = Action('SwapEnvironmentCNAMEs')
TerminateEnvironment = Action('TerminateEnvironment')
UpdateApplication = Action('UpdateApplication')
UpdateApplicationResourceLifecycle = \
    Action('UpdateApplicationResourceLifecycle')
UpdateApplicationVersion = Action('UpdateApplicationVersion')
UpdateConfigurationTemplate = Action('UpdateConfigurationTemplate')
UpdateEnvironment = Action('UpdateEnvironment')
ValidateConfigurationSettings = Action('ValidateConfigurationSettings')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon WorkLink'
prefix = 'worklink'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateDomain = Action('AssociateDomain')
AssociateWebsiteAuthorizationProvider = \
    Action('AssociateWebsiteAuthorizationProvider')
AssociateWebsiteCertificateAuthority = \
    Action('AssociateWebsiteCertificateAuthority')
CreateFleet = Action('CreateFleet')
DeleteFleet = Action('DeleteFleet')
DescribeAuditStreamConfiguration = \
    Action('DescribeAuditStreamConfiguration')
DescribeCompanyNetworkConfiguration = \
    Action('DescribeCompanyNetworkConfiguration')
DescribeDevice = Action('DescribeDevice')
DescribeDevicePolicyConfiguration = \
    Action('DescribeDevicePolicyConfiguration')
DescribeDomain = Action('DescribeDomain')
DescribeFleetMetadata = Action('DescribeFleetMetadata')
DescribeIdentityProviderConfiguration = \
    Action('DescribeIdentityProviderConfiguration')
DescribeWebsiteCertificateAuthority = \
    Action('DescribeWebsiteCertificateAuthority')
DisassociateDomain = Action('DisassociateDomain')
DisassociateWebsiteAuthorizationProvider = \
    Action('DisassociateWebsiteAuthorizationProvider')
DisassociateWebsiteCertificateAuthority = \
    Action('DisassociateWebsiteCertificateAuthority')
ListDevices = Action('ListDevices')
ListDomains = Action('ListDomains')
ListFleets = Action('ListFleets')
ListTagsForResource = Action('ListTagsForResource')
ListWebsiteAuthorizationProviders = \
    Action('ListWebsiteAuthorizationProviders')
ListWebsiteCertificateAuthorities = \
    Action('ListWebsiteCertificateAuthorities')
RestoreDomainAccess = Action('RestoreDomainAccess')
RevokeDomainAccess = Action('RevokeDomainAccess')
SignOutUser = Action('SignOutUser')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateAuditStreamConfiguration = Action('UpdateAuditStreamConfiguration')
UpdateCompanyNetworkConfiguration = \
    Action('UpdateCompanyNetworkConfiguration')
UpdateDevicePolicyConfiguration = \
    Action('UpdateDevicePolicyConfiguration')
UpdateDomainMetadata = Action('UpdateDomainMetadata')
UpdateFleetMetadata = Action('UpdateFleetMetadata')
UpdateIdentityProviderConfiguration = \
    Action('UpdateIdentityProviderConfiguration')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CodeStar'
prefix = 'codestar'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateTeamMember = Action('AssociateTeamMember')
CreateProject = Action('CreateProject')
CreateUserProfile = Action('CreateUserProfile')
DeleteExtendedAccess = Action('DeleteExtendedAccess')
DeleteProject = Action('DeleteProject')
DeleteUserProfile = Action('DeleteUserProfile')
DescribeProject = Action('DescribeProject')
DescribeUserProfile = Action('DescribeUserProfile')
DisassociateTeamMember = Action('DisassociateTeamMember')
GetExtendedAccess = Action('GetExtendedAccess')
ListProjects = Action('ListProjects')
ListResources = Action('ListResources')
ListTagsForProject = Action('ListTagsForProject')
ListTeamMembers = Action('ListTeamMembers')
ListUserProfiles = Action('ListUserProfiles')
PutExtendedAccess = Action('PutExtendedAccess')
TagProject = Action('TagProject')
UntagProject = Action('UntagProject')
UpdateProject = Action('UpdateProject')
UpdateTeamMember = Action('UpdateTeamMember')
UpdateUserProfile = Action('UpdateUserProfile')
VerifyServiceRole = Action('VerifyServiceRole')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

import inspect
import json
import re
import types

__version__ = "0.9.9"

valid_names = re.compile(r'^[a-zA-Z0-9]+$')


class AWSObject(object):
    def __init__(self, name, type=None, dictname=None, props={}, **kwargs):
        self.name = name
        self.props = props
        # Cache the keys for validity checks
        self.propnames = props.keys()

        # unset/None is also legal
        if name and not valid_names.match(name):
            raise ValueError('Name not alphanumeric')

        # Create the list of properties set on this object by the user
        self.properties = {}
        if dictname:
            self.resource = {
                dictname: self.properties,
            }
        else:
            self.resource = self.properties
        self.__initialized = True

        # Now that it is initialized, populate it with the kwargs
        for k, v in kwargs.items():
            self.__setattr__(k, v)

    def __getattr__(self, name):
        try:
            return self.properties.__getitem__(name)
        except KeyError:
            raise AttributeError(name)

    def __setattr__(self, name, value):
        if '_AWSObject__initialized' not in self.__dict__:
            return dict.__setattr__(self, name, value)
        elif name in self.propnames:
            # Check the type of the object and compare against what we were
            # expecting.
            expected_type = self.props[name][0]

            # If it's a function, call it...
            if isinstance(expected_type, types.FunctionType):
                value = expected_type(value)
                return self.properties.__setitem__(name, value)

            # If it's a list of types, check against those types...
            elif isinstance(expected_type, list):
                # If we're expecting a list, then make sure it is a list
                if not isinstance(value, list):
                    self._raise_type(name, value, expected_type)

                # Iterate over the list and make sure it matches our
                # type checks
                for v in value:
                    if not isinstance(v, tuple(expected_type)):
                        self._raise_type(name, v, expected_type)
                # Validated so assign it
                return self.properties.__setitem__(name, value)

            # Single type so check the type of the object and compare against
            # what we were expecting. Special case AWS helper functions and its
            # sub classes. Also handles AWS helper functions from other
            # libraries like cloudtools/troposphere.
            elif isinstance(value, expected_type) or \
                    'AWSHelperFn' in [c.__name__
                                      for c in inspect.getmro(type(value))]:
                return self.properties.__setitem__(name, value)
            else:
                self._raise_type(name, value, expected_type)

        full_class_name = "%s.%s" % (self.__class__.__module__,
                                     self.__class__.__name__)
        raise AttributeError("'%s' object does not support attribute '%s'" %
                             (full_class_name, name))

    def _raise_type(self, name, value, expected_type):
        raise TypeError('%s is %s, expected %s' %
                        (name, type(value), expected_type))

    def validate(self):
        pass

    def JSONrepr(self):
        for k, v in self.props.items():
            if v[1] and k not in self.properties:
                raise ValueError("Resource %s required in type %s" %
                                 (k, type(self)))
        self.validate()
        return self.resource

    def to_json(self, indent=4, sort_keys=True):
        p = self.properties
        return json.dumps(p, cls=awsencode, indent=indent, sort_keys=sort_keys)

    def __eq__(self, other):
        if isinstance(other, self.__class__):
            return self.to_json() == other.to_json()
        else:
            return False

    def __ne__(self, other):
        return not self == other

    def __hash__(self):
        return hash(self.to_json())


class AWSProperty(AWSObject):
    """
    Used for CloudFormation Resource Property objects
    http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/
    aws-product-property-reference.html
    """

    def __init__(self, **kwargs):
        sup = super(AWSProperty, self)
        sup.__init__(None, props=self.props, **kwargs)


class AWSHelperFn(object):
    def getdata(self, data):
        if isinstance(data, AWSObject):
            return data.name
        else:
            return data

    def to_json(self, indent=4, sort_keys=True):
        p = self
        return json.dumps(p, cls=awsencode, indent=indent, sort_keys=sort_keys)

    def __eq__(self, other):
        if isinstance(other, self.__class__):
            return self.to_json() == other.to_json()
        else:
            return False

    def __ne__(self, other):
        return not self == other

    def __hash__(self):
        return hash(self.to_json())


class awsencode(json.JSONEncoder):
    def default(self, obj):
        if hasattr(obj, 'JSONrepr'):
            return obj.JSONrepr()
        return json.JSONEncoder.default(self, obj)



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Route 53 Auto Naming'
prefix = 'servicediscovery'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateHttpNamespace = Action('CreateHttpNamespace')
CreatePrivateDnsNamespace = Action('CreatePrivateDnsNamespace')
CreatePublicDnsNamespace = Action('CreatePublicDnsNamespace')
CreateService = Action('CreateService')
DeleteNamespace = Action('DeleteNamespace')
DeleteService = Action('DeleteService')
DeregisterInstance = Action('DeregisterInstance')
DiscoverInstances = Action('DiscoverInstances')
GetInstance = Action('GetInstance')
GetInstancesHealthStatus = Action('GetInstancesHealthStatus')
GetNamespace = Action('GetNamespace')
GetOperation = Action('GetOperation')
GetService = Action('GetService')
ListInstances = Action('ListInstances')
ListNamespaces = Action('ListNamespaces')
ListOperations = Action('ListOperations')
ListServices = Action('ListServices')
ListTagsForResource = Action('ListTagsForResource')
RegisterInstance = Action('RegisterInstance')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateInstanceCustomHealthStatus = \
    Action('UpdateInstanceCustomHealthStatus')
UpdateInstanceHeartbeatStatus = Action('UpdateInstanceHeartbeatStatus')
UpdateService = Action('UpdateService')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon AWS Cloud Contact Center'
prefix = 'connect'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateRoutingProfileQueues = Action('AssociateRoutingProfileQueues')
CreateContactFlow = Action('CreateContactFlow')
CreateInstance = Action('CreateInstance')
CreateRoutingProfile = Action('CreateRoutingProfile')
CreateUser = Action('CreateUser')
DeleteUser = Action('DeleteUser')
DescribeContactFlow = Action('DescribeContactFlow')
DescribeInstance = Action('DescribeInstance')
DescribeRoutingProfile = Action('DescribeRoutingProfile')
DescribeUser = Action('DescribeUser')
DescribeUserHierarchyGroup = Action('DescribeUserHierarchyGroup')
DescribeUserHierarchyStructure = Action('DescribeUserHierarchyStructure')
DestroyInstance = Action('DestroyInstance')
DisassociateRoutingProfileQueues = \
    Action('DisassociateRoutingProfileQueues')
GetContactAttributes = Action('GetContactAttributes')
GetCurrentMetricData = Action('GetCurrentMetricData')
GetFederationToken = Action('GetFederationToken')
GetFederationTokens = Action('GetFederationTokens')
GetMetricData = Action('GetMetricData')
ListContactFlows = Action('ListContactFlows')
ListHoursOfOperations = Action('ListHoursOfOperations')
ListInstances = Action('ListInstances')
ListPhoneNumbers = Action('ListPhoneNumbers')
ListPrompts = Action('ListPrompts')
ListQueues = Action('ListQueues')
ListRoutingProfileQueues = Action('ListRoutingProfileQueues')
ListRoutingProfiles = Action('ListRoutingProfiles')
ListSecurityProfiles = Action('ListSecurityProfiles')
ListTagsForResource = Action('ListTagsForResource')
ListUserHierarchyGroups = Action('ListUserHierarchyGroups')
ListUsers = Action('ListUsers')
ModifyInstance = Action('ModifyInstance')
ResumeContactRecording = Action('ResumeContactRecording')
StartChatContact = Action('StartChatContact')
StartContactRecording = Action('StartContactRecording')
StartOutboundVoiceContact = Action('StartOutboundVoiceContact')
StopContact = Action('StopContact')
StopContactRecording = Action('StopContactRecording')
SuspendContactRecording = Action('SuspendContactRecording')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateContactAttributes = Action('UpdateContactAttributes')
UpdateContactFlowContent = Action('UpdateContactFlowContent')
UpdateContactFlowName = Action('UpdateContactFlowName')
UpdateRoutingProfileConcurrency = \
    Action('UpdateRoutingProfileConcurrency')
UpdateRoutingProfileDefaultOutboundQueue = \
    Action('UpdateRoutingProfileDefaultOutboundQueue')
UpdateRoutingProfileName = Action('UpdateRoutingProfileName')
UpdateRoutingProfileQueues = Action('UpdateRoutingProfileQueues')
UpdateUserHierarchy = Action('UpdateUserHierarchy')
UpdateUserIdentityInfo = Action('UpdateUserIdentityInfo')
UpdateUserPhoneConfig = Action('UpdateUserPhoneConfig')
UpdateUserRoutingProfile = Action('UpdateUserRoutingProfile')
UpdateUserSecurityProfiles = Action('UpdateUserSecurityProfiles')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS AppSync'
prefix = 'appsync'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateApiKey = Action('CreateApiKey')
CreateDataSource = Action('CreateDataSource')
CreateFunction = Action('CreateFunction')
CreateGraphqlApi = Action('CreateGraphqlApi')
CreateResolver = Action('CreateResolver')
CreateType = Action('CreateType')
DeleteApiKey = Action('DeleteApiKey')
DeleteDataSource = Action('DeleteDataSource')
DeleteFunction = Action('DeleteFunction')
DeleteGraphqlApi = Action('DeleteGraphqlApi')
DeleteResolver = Action('DeleteResolver')
DeleteType = Action('DeleteType')
GetDataSource = Action('GetDataSource')
GetFunction = Action('GetFunction')
GetGraphqlApi = Action('GetGraphqlApi')
GetIntrospectionSchema = Action('GetIntrospectionSchema')
GetResolver = Action('GetResolver')
GetSchemaCreationStatus = Action('GetSchemaCreationStatus')
GetType = Action('GetType')
GraphQL = Action('GraphQL')
ListApiKeys = Action('ListApiKeys')
ListDataSources = Action('ListDataSources')
ListFunctions = Action('ListFunctions')
ListGraphqlApis = Action('ListGraphqlApis')
ListResolvers = Action('ListResolvers')
ListResolversByFunction = Action('ListResolversByFunction')
ListTagsForResource = Action('ListTagsForResource')
ListTypes = Action('ListTypes')
StartSchemaCreation = Action('StartSchemaCreation')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateApiKey = Action('UpdateApiKey')
UpdateDataSource = Action('UpdateDataSource')
UpdateFunction = Action('UpdateFunction')
UpdateGraphqlApi = Action('UpdateGraphqlApi')
UpdateResolver = Action('UpdateResolver')
UpdateType = Action('UpdateType')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'QuickSight'
prefix = 'quicksight'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateAdmin = Action('CreateAdmin')
CreateDashboard = Action('CreateDashboard')
CreateGroup = Action('CreateGroup')
CreateGroupMembership = Action('CreateGroupMembership')
CreateIAMPolicyAssignment = Action('CreateIAMPolicyAssignment')
CreateReader = Action('CreateReader')
CreateTemplate = Action('CreateTemplate')
CreateTemplateAlias = Action('CreateTemplateAlias')
CreateTheme = Action('CreateTheme')
CreateThemeAlias = Action('CreateThemeAlias')
CreateUser = Action('CreateUser')
DeleteDashboard = Action('DeleteDashboard')
DeleteGroup = Action('DeleteGroup')
DeleteGroupMembership = Action('DeleteGroupMembership')
DeleteIAMPolicyAssignment = Action('DeleteIAMPolicyAssignment')
DeleteTemplate = Action('DeleteTemplate')
DeleteTemplateAlias = Action('DeleteTemplateAlias')
DeleteTheme = Action('DeleteTheme')
DeleteThemeAlias = Action('DeleteThemeAlias')
DeleteUser = Action('DeleteUser')
DeleteUserByPrincipalId = Action('DeleteUserByPrincipalId')
DescribeDashboard = Action('DescribeDashboard')
DescribeDashboardPermissions = Action('DescribeDashboardPermissions')
DescribeGroup = Action('DescribeGroup')
DescribeIAMPolicyAssignment = Action('DescribeIAMPolicyAssignment')
DescribeTemplate = Action('DescribeTemplate')
DescribeTemplateAlias = Action('DescribeTemplateAlias')
DescribeTemplatePermissions = Action('DescribeTemplatePermissions')
DescribeTheme = Action('DescribeTheme')
DescribeThemeAlias = Action('DescribeThemeAlias')
DescribeThemePermissions = Action('DescribeThemePermissions')
DescribeUser = Action('DescribeUser')
GetAuthCode = Action('GetAuthCode')
GetDashboardEmbedUrl = Action('GetDashboardEmbedUrl')
GetGroupMapping = Action('GetGroupMapping')
ListDashboardVersions = Action('ListDashboardVersions')
ListDashboards = Action('ListDashboards')
ListGroupMemberships = Action('ListGroupMemberships')
ListGroups = Action('ListGroups')
ListIAMPolicyAssignments = Action('ListIAMPolicyAssignments')
ListIAMPolicyAssignmentsForUser = \
    Action('ListIAMPolicyAssignmentsForUser')
ListTagsForResource = Action('ListTagsForResource')
ListTemplateAliases = Action('ListTemplateAliases')
ListTemplateVersions = Action('ListTemplateVersions')
ListTemplates = Action('ListTemplates')
ListThemeAliases = Action('ListThemeAliases')
ListThemeVersions = Action('ListThemeVersions')
ListThemes = Action('ListThemes')
ListUserGroups = Action('ListUserGroups')
ListUsers = Action('ListUsers')
RegisterUser = Action('RegisterUser')
SearchDirectoryGroups = Action('SearchDirectoryGroups')
SetGroupMapping = Action('SetGroupMapping')
Subscribe = Action('Subscribe')
TagResource = Action('TagResource')
Unsubscribe = Action('Unsubscribe')
UntagResource = Action('UntagResource')
UpdateDashboard = Action('UpdateDashboard')
UpdateDashboardPermissions = Action('UpdateDashboardPermissions')
UpdateDashboardPublishedVersion = \
    Action('UpdateDashboardPublishedVersion')
UpdateGroup = Action('UpdateGroup')
UpdateIAMPolicyAssignment = Action('UpdateIAMPolicyAssignment')
UpdateTemplate = Action('UpdateTemplate')
UpdateTemplateAlias = Action('UpdateTemplateAlias')
UpdateTemplatePermissions = Action('UpdateTemplatePermissions')
UpdateTheme = Action('UpdateTheme')
UpdateThemeAlias = Action('UpdateThemeAlias')
UpdateThemePermissions = Action('UpdateThemePermissions')
UpdateUser = Action('UpdateUser')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CodePipeline'
prefix = 'codepipeline'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcknowledgeJob = Action('AcknowledgeJob')
AcknowledgeThirdPartyJob = Action('AcknowledgeThirdPartyJob')
CreateCustomActionType = Action('CreateCustomActionType')
CreatePipeline = Action('CreatePipeline')
DeleteCustomActionType = Action('DeleteCustomActionType')
DeletePipeline = Action('DeletePipeline')
DeleteWebhook = Action('DeleteWebhook')
DeregisterWebhookWithThirdParty = \
    Action('DeregisterWebhookWithThirdParty')
DisableStageTransition = Action('DisableStageTransition')
EnableStageTransition = Action('EnableStageTransition')
GetJobDetails = Action('GetJobDetails')
GetPipeline = Action('GetPipeline')
GetPipelineExecution = Action('GetPipelineExecution')
GetPipelineState = Action('GetPipelineState')
GetThirdPartyJobDetails = Action('GetThirdPartyJobDetails')
ListActionExecutions = Action('ListActionExecutions')
ListActionTypes = Action('ListActionTypes')
ListPipelineExecutions = Action('ListPipelineExecutions')
ListPipelines = Action('ListPipelines')
ListTagsForResource = Action('ListTagsForResource')
ListWebhooks = Action('ListWebhooks')
PollForJobs = Action('PollForJobs')
PollForThirdPartyJobs = Action('PollForThirdPartyJobs')
PutActionRevision = Action('PutActionRevision')
PutApprovalResult = Action('PutApprovalResult')
PutJobFailureResult = Action('PutJobFailureResult')
PutJobSuccessResult = Action('PutJobSuccessResult')
PutThirdPartyJobFailureResult = Action('PutThirdPartyJobFailureResult')
PutThirdPartyJobSuccessResult = Action('PutThirdPartyJobSuccessResult')
PutWebhook = Action('PutWebhook')
RegisterWebhookWithThirdParty = Action('RegisterWebhookWithThirdParty')
RetryStageExecution = Action('RetryStageExecution')
StartPipelineExecution = Action('StartPipelineExecution')
StopPipelineExecution = Action('StopPipelineExecution')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdatePipeline = Action('UpdatePipeline')



import warnings
# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon SQS'
prefix = 'sqs'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


class SQS_ARN(ARN):
    def __init__(self, *args, **kwargs):
        super(SQS_ARN, self).__init__(*args, **kwargs)
        warnings.warn("This class is going away. Use sqs.ARN instead.",
                      FutureWarning)


AddPermission = Action('AddPermission')
ChangeMessageVisibility = Action('ChangeMessageVisibility')
ChangeMessageVisibilityBatch = Action('ChangeMessageVisibilityBatch')
CreateQueue = Action('CreateQueue')
DeleteMessage = Action('DeleteMessage')
DeleteMessageBatch = Action('DeleteMessageBatch')
DeleteQueue = Action('DeleteQueue')
GetQueueAttributes = Action('GetQueueAttributes')
GetQueueUrl = Action('GetQueueUrl')
ListDeadLetterSourceQueues = Action('ListDeadLetterSourceQueues')
ListQueueTags = Action('ListQueueTags')
ListQueues = Action('ListQueues')
PurgeQueue = Action('PurgeQueue')
ReceiveMessage = Action('ReceiveMessage')
RemovePermission = Action('RemovePermission')
SendMessage = Action('SendMessage')
SendMessageBatch = Action('SendMessageBatch')
SetQueueAttributes = Action('SetQueueAttributes')
TagQueue = Action('TagQueue')
UntagQueue = Action('UntagQueue')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Transcribe'
prefix = 'transcribe'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateLanguageModel = Action('CreateLanguageModel')
CreateMedicalVocabulary = Action('CreateMedicalVocabulary')
CreateVocabulary = Action('CreateVocabulary')
CreateVocabularyFilter = Action('CreateVocabularyFilter')
DeleteLanguageModel = Action('DeleteLanguageModel')
DeleteMedicalTranscriptionJob = Action('DeleteMedicalTranscriptionJob')
DeleteMedicalVocabulary = Action('DeleteMedicalVocabulary')
DeleteTranscriptionJob = Action('DeleteTranscriptionJob')
DeleteVocabulary = Action('DeleteVocabulary')
DeleteVocabularyFilter = Action('DeleteVocabularyFilter')
DescribeLanguageModel = Action('DescribeLanguageModel')
GetMedicalTranscriptionJob = Action('GetMedicalTranscriptionJob')
GetMedicalVocabulary = Action('GetMedicalVocabulary')
GetTranscriptionJob = Action('GetTranscriptionJob')
GetVocabulary = Action('GetVocabulary')
GetVocabularyFilter = Action('GetVocabularyFilter')
ListLanguageModels = Action('ListLanguageModels')
ListMedicalTranscriptionJobs = Action('ListMedicalTranscriptionJobs')
ListMedicalVocabularies = Action('ListMedicalVocabularies')
ListTranscriptionJobs = Action('ListTranscriptionJobs')
ListVocabularies = Action('ListVocabularies')
ListVocabularyFilters = Action('ListVocabularyFilters')
StartMedicalStreamTranscription = \
    Action('StartMedicalStreamTranscription')
StartMedicalStreamTranscriptionWebSocket = \
    Action('StartMedicalStreamTranscriptionWebSocket')
StartMedicalTranscriptionJob = Action('StartMedicalTranscriptionJob')
StartStreamTranscription = Action('StartStreamTranscription')
StartStreamTranscriptionWebSocket = \
    Action('StartStreamTranscriptionWebSocket')
StartTranscriptionJob = Action('StartTranscriptionJob')
UpdateMedicalVocabulary = Action('UpdateMedicalVocabulary')
UpdateVocabulary = Action('UpdateVocabulary')
UpdateVocabularyFilter = Action('UpdateVocabularyFilter')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS IoT Events'
prefix = 'iotevents'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchPutMessage = Action('BatchPutMessage')
BatchUpdateDetector = Action('BatchUpdateDetector')
CreateDetectorModel = Action('CreateDetectorModel')
CreateInput = Action('CreateInput')
DeleteDetectorModel = Action('DeleteDetectorModel')
DeleteInput = Action('DeleteInput')
DescribeDetector = Action('DescribeDetector')
DescribeDetectorModel = Action('DescribeDetectorModel')
DescribeInput = Action('DescribeInput')
DescribeLoggingOptions = Action('DescribeLoggingOptions')
ListDetectorModelVersions = Action('ListDetectorModelVersions')
ListDetectorModels = Action('ListDetectorModels')
ListDetectors = Action('ListDetectors')
ListInputs = Action('ListInputs')
ListTagsForResource = Action('ListTagsForResource')
PutLoggingOptions = Action('PutLoggingOptions')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDetectorModel = Action('UpdateDetectorModel')
UpdateInput = Action('UpdateInput')
UpdateInputRouting = Action('UpdateInputRouting')



import json
import unittest

import awacs
from awacs.aws import Action, PolicyDocument


class AWSHelperFn(object):
    """Mock class to test classes with non-awacs AWSHelperFn parent."""

    def to_json(self, indent=4, sort_keys=True):
        p = self
        return json.dumps(p, cls=awacs.awsencode, indent=indent,
                          sort_keys=sort_keys)

    def __eq__(self, other):
        if isinstance(other, self.__class__):
            return self.to_json() == other.to_json()
        else:
            return False


class AWSHelperFnChild(AWSHelperFn):
    """Child class of non-awacs AWSHelperFn."""

    def __init__(self, **kwargs):
        """Instantiate class."""
        for key, val in kwargs.items():
            setattr(self, key, val)

    def JSONrepr(self):
        """JSON serialization."""
        return self.__dict__


class TypeValidationObject(awacs.AWSProperty):
    """Subclass the AWSObject to test its functionality."""

    props = {
        'ExpectList': (list, False)
    }


class TestAWSObject(unittest.TestCase):
    def test_invalid_property(self):
        with self.assertRaises(AttributeError) as exc:
            # statement should be Statement
            PolicyDocument(Version='2012-10-17', statement=[])

        self.assertEqual(
            exc.exception.args[0],
            "'awacs.aws.PolicyDocument' object does not support attribute "
            "'statement'"
        )


class TestAWSProperty(unittest.TestCase):
    def test_prop_value_type_mismatch_expect_list(self):
        class InvalidClass(object):
            """Class of invalid type."""

        tests_values = [
            'val',
            {'key': 'val'},
            {'val'},
            tuple('val'),
            InvalidClass()
        ]

        for val in tests_values:
            with self.assertRaises(TypeError) as exc:
                TypeValidationObject(ExpectList=val)
            self.assertEqual(
                exc.exception.args[0],
                "ExpectList is %s, expected %s" % (type(val), type(list()))
            )

    def test_prop_value_type_expect_list(self):
        tests_values = [
            ['val'],
            Action('s3', '*'),
            AWSHelperFnChild(key='val')
        ]

        for val in tests_values:
            self.assertEqual(TypeValidationObject(ExpectList=val).ExpectList,
                             val)



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Lex'
prefix = 'lex'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateBotVersion = Action('CreateBotVersion')
CreateIntentVersion = Action('CreateIntentVersion')
CreateSlotTypeVersion = Action('CreateSlotTypeVersion')
DeleteBot = Action('DeleteBot')
DeleteBotAlias = Action('DeleteBotAlias')
DeleteBotChannelAssociation = Action('DeleteBotChannelAssociation')
DeleteBotVersion = Action('DeleteBotVersion')
DeleteIntent = Action('DeleteIntent')
DeleteIntentVersion = Action('DeleteIntentVersion')
DeleteSession = Action('DeleteSession')
DeleteSlotType = Action('DeleteSlotType')
DeleteSlotTypeVersion = Action('DeleteSlotTypeVersion')
DeleteUtterances = Action('DeleteUtterances')
GetBot = Action('GetBot')
GetBotAlias = Action('GetBotAlias')
GetBotAliases = Action('GetBotAliases')
GetBotChannelAssociation = Action('GetBotChannelAssociation')
GetBotChannelAssociations = Action('GetBotChannelAssociations')
GetBotVersions = Action('GetBotVersions')
GetBots = Action('GetBots')
GetBuiltinIntent = Action('GetBuiltinIntent')
GetBuiltinIntents = Action('GetBuiltinIntents')
GetBuiltinSlotTypes = Action('GetBuiltinSlotTypes')
GetExport = Action('GetExport')
GetImport = Action('GetImport')
GetIntent = Action('GetIntent')
GetIntentVersions = Action('GetIntentVersions')
GetIntents = Action('GetIntents')
GetSession = Action('GetSession')
GetSlotType = Action('GetSlotType')
GetSlotTypeVersions = Action('GetSlotTypeVersions')
GetSlotTypes = Action('GetSlotTypes')
GetUtterancesView = Action('GetUtterancesView')
ListTagsForResource = Action('ListTagsForResource')
PostContent = Action('PostContent')
PostText = Action('PostText')
PutBot = Action('PutBot')
PutBotAlias = Action('PutBotAlias')
PutIntent = Action('PutIntent')
PutSession = Action('PutSession')
PutSlotType = Action('PutSlotType')
StartImport = Action('StartImport')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Auto Scaling'
prefix = 'autoscaling'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AttachInstances = Action('AttachInstances')
AttachLoadBalancerTargetGroups = Action('AttachLoadBalancerTargetGroups')
AttachLoadBalancers = Action('AttachLoadBalancers')
BatchDeleteScheduledAction = Action('BatchDeleteScheduledAction')
BatchPutScheduledUpdateGroupAction = \
    Action('BatchPutScheduledUpdateGroupAction')
CancelInstanceRefresh = Action('CancelInstanceRefresh')
CompleteLifecycleAction = Action('CompleteLifecycleAction')
CreateAutoScalingGroup = Action('CreateAutoScalingGroup')
CreateLaunchConfiguration = Action('CreateLaunchConfiguration')
CreateOrUpdateTags = Action('CreateOrUpdateTags')
DeleteAutoScalingGroup = Action('DeleteAutoScalingGroup')
DeleteLaunchConfiguration = Action('DeleteLaunchConfiguration')
DeleteLifecycleHook = Action('DeleteLifecycleHook')
DeleteNotificationConfiguration = \
    Action('DeleteNotificationConfiguration')
DeletePolicy = Action('DeletePolicy')
DeleteScheduledAction = Action('DeleteScheduledAction')
DeleteTags = Action('DeleteTags')
DescribeAccountLimits = Action('DescribeAccountLimits')
DescribeAdjustmentTypes = Action('DescribeAdjustmentTypes')
DescribeAutoScalingGroups = Action('DescribeAutoScalingGroups')
DescribeAutoScalingInstances = Action('DescribeAutoScalingInstances')
DescribeAutoScalingNotificationTypes = \
    Action('DescribeAutoScalingNotificationTypes')
DescribeInstanceRefreshes = Action('DescribeInstanceRefreshes')
DescribeLaunchConfigurations = Action('DescribeLaunchConfigurations')
DescribeLifecycleHookTypes = Action('DescribeLifecycleHookTypes')
DescribeLifecycleHooks = Action('DescribeLifecycleHooks')
DescribeLoadBalancerTargetGroups = \
    Action('DescribeLoadBalancerTargetGroups')
DescribeLoadBalancers = Action('DescribeLoadBalancers')
DescribeMetricCollectionTypes = Action('DescribeMetricCollectionTypes')
DescribeNotificationConfigurations = \
    Action('DescribeNotificationConfigurations')
DescribePolicies = Action('DescribePolicies')
DescribeScalingActivities = Action('DescribeScalingActivities')
DescribeScalingProcessTypes = Action('DescribeScalingProcessTypes')
DescribeScheduledActions = Action('DescribeScheduledActions')
DescribeTags = Action('DescribeTags')
DescribeTerminationPolicyTypes = Action('DescribeTerminationPolicyTypes')
DetachInstances = Action('DetachInstances')
DetachLoadBalancerTargetGroups = Action('DetachLoadBalancerTargetGroups')
DetachLoadBalancers = Action('DetachLoadBalancers')
DisableMetricsCollection = Action('DisableMetricsCollection')
EnableMetricsCollection = Action('EnableMetricsCollection')
EnterStandby = Action('EnterStandby')
ExecutePolicy = Action('ExecutePolicy')
ExitStandby = Action('ExitStandby')
PutLifecycleHook = Action('PutLifecycleHook')
PutNotificationConfiguration = Action('PutNotificationConfiguration')
PutScalingPolicy = Action('PutScalingPolicy')
PutScheduledUpdateGroupAction = Action('PutScheduledUpdateGroupAction')
RecordLifecycleActionHeartbeat = Action('RecordLifecycleActionHeartbeat')
ResumeProcesses = Action('ResumeProcesses')
SetDesiredCapacity = Action('SetDesiredCapacity')
SetInstanceHealth = Action('SetInstanceHealth')
SetInstanceProtection = Action('SetInstanceProtection')
StartInstanceRefresh = Action('StartInstanceRefresh')
SuspendProcesses = Action('SuspendProcesses')
TerminateInstanceInAutoScalingGroup = \
    Action('TerminateInstanceInAutoScalingGroup')
UpdateAutoScalingGroup = Action('UpdateAutoScalingGroup')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Macie'
prefix = 'macie'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptInvitation = Action('AcceptInvitation')
ArchiveFindings = Action('ArchiveFindings')
AssociateMemberAccount = Action('AssociateMemberAccount')
AssociateS3Resources = Action('AssociateS3Resources')
BatchGetCustomDataIdentifiers = Action('BatchGetCustomDataIdentifiers')
CreateClassificationJob = Action('CreateClassificationJob')
CreateCustomDataIdentifier = Action('CreateCustomDataIdentifier')
CreateFindingsFilter = Action('CreateFindingsFilter')
CreateInvitations = Action('CreateInvitations')
CreateMember = Action('CreateMember')
CreateSampleFindings = Action('CreateSampleFindings')
DeclineInvitations = Action('DeclineInvitations')
DeleteCustomDataIdentifier = Action('DeleteCustomDataIdentifier')
DeleteFindingsFilter = Action('DeleteFindingsFilter')
DeleteInvitations = Action('DeleteInvitations')
DeleteMember = Action('DeleteMember')
DescribeBuckets = Action('DescribeBuckets')
DescribeClassificationJob = Action('DescribeClassificationJob')
DescribeOrganizationConfiguration = \
    Action('DescribeOrganizationConfiguration')
DisableMacie = Action('DisableMacie')
DisableOrganizationAdminAccount = \
    Action('DisableOrganizationAdminAccount')
DisassociateFromMasterAccount = Action('DisassociateFromMasterAccount')
DisassociateMember = Action('DisassociateMember')
DisassociateMemberAccount = Action('DisassociateMemberAccount')
DisassociateS3Resources = Action('DisassociateS3Resources')
EnableMacie = Action('EnableMacie')
EnableOrganizationAdminAccount = Action('EnableOrganizationAdminAccount')
GetBucketStatistics = Action('GetBucketStatistics')
GetClassificationExportConfiguration = \
    Action('GetClassificationExportConfiguration')
GetCustomDataIdentifier = Action('GetCustomDataIdentifier')
GetFindingStatistics = Action('GetFindingStatistics')
GetFindings = Action('GetFindings')
GetFindingsFilter = Action('GetFindingsFilter')
GetInvitationsCount = Action('GetInvitationsCount')
GetMacieSession = Action('GetMacieSession')
GetMasterAccount = Action('GetMasterAccount')
GetMember = Action('GetMember')
GetUsageStatistics = Action('GetUsageStatistics')
GetUsageTotals = Action('GetUsageTotals')
ListClassificationJobs = Action('ListClassificationJobs')
ListCustomDataIdentifiers = Action('ListCustomDataIdentifiers')
ListFindings = Action('ListFindings')
ListFindingsFilters = Action('ListFindingsFilters')
ListInvitations = Action('ListInvitations')
ListMemberAccounts = Action('ListMemberAccounts')
ListMembers = Action('ListMembers')
ListOrganizationAdminAccounts = Action('ListOrganizationAdminAccounts')
ListS3Resources = Action('ListS3Resources')
ListTagsForResources = Action('ListTagsForResources')
PutClassificationExportConfiguration = \
    Action('PutClassificationExportConfiguration')
TagResource = Action('TagResource')
TestCustomDataIdentifier = Action('TestCustomDataIdentifier')
UnarchiveFindings = Action('UnarchiveFindings')
UntagResource = Action('UntagResource')
UpdateClassificationJob = Action('UpdateClassificationJob')
UpdateFindingsFilter = Action('UpdateFindingsFilter')
UpdateMemberSession = Action('UpdateMemberSession')
UpdateOrganizationConfiguration = \
    Action('UpdateOrganizationConfiguration')
UpdateS3Resources = Action('UpdateS3Resources')
UpdateSession = Action('UpdateSession')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Lightsail'
prefix = 'lightsail'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AllocateStaticIp = Action('AllocateStaticIp')
AttachDisk = Action('AttachDisk')
AttachInstancesToLoadBalancer = Action('AttachInstancesToLoadBalancer')
AttachLoadBalancerTlsCertificate = \
    Action('AttachLoadBalancerTlsCertificate')
AttachStaticIp = Action('AttachStaticIp')
CloseInstancePublicPorts = Action('CloseInstancePublicPorts')
CopySnapshot = Action('CopySnapshot')
CreateCloudFormationStack = Action('CreateCloudFormationStack')
CreateDisk = Action('CreateDisk')
CreateDiskFromSnapshot = Action('CreateDiskFromSnapshot')
CreateDiskSnapshot = Action('CreateDiskSnapshot')
CreateDomain = Action('CreateDomain')
CreateDomainEntry = Action('CreateDomainEntry')
CreateInstanceSnapshot = Action('CreateInstanceSnapshot')
CreateInstances = Action('CreateInstances')
CreateInstancesFromSnapshot = Action('CreateInstancesFromSnapshot')
CreateKeyPair = Action('CreateKeyPair')
CreateLoadBalancer = Action('CreateLoadBalancer')
CreateLoadBalancerTlsCertificate = \
    Action('CreateLoadBalancerTlsCertificate')
CreateRelationalDatabase = Action('CreateRelationalDatabase')
CreateRelationalDatabaseFromSnapshot = \
    Action('CreateRelationalDatabaseFromSnapshot')
CreateRelationalDatabaseSnapshot = \
    Action('CreateRelationalDatabaseSnapshot')
DeleteDisk = Action('DeleteDisk')
DeleteDiskSnapshot = Action('DeleteDiskSnapshot')
DeleteDomain = Action('DeleteDomain')
DeleteDomainEntry = Action('DeleteDomainEntry')
DeleteInstance = Action('DeleteInstance')
DeleteInstanceSnapshot = Action('DeleteInstanceSnapshot')
DeleteKeyPair = Action('DeleteKeyPair')
DeleteKnownHostKeys = Action('DeleteKnownHostKeys')
DeleteLoadBalancer = Action('DeleteLoadBalancer')
DeleteLoadBalancerTlsCertificate = \
    Action('DeleteLoadBalancerTlsCertificate')
DeleteRelationalDatabase = Action('DeleteRelationalDatabase')
DeleteRelationalDatabaseSnapshot = \
    Action('DeleteRelationalDatabaseSnapshot')
DetachDisk = Action('DetachDisk')
DetachInstancesFromLoadBalancer = \
    Action('DetachInstancesFromLoadBalancer')
DetachStaticIp = Action('DetachStaticIp')
DownloadDefaultKeyPair = Action('DownloadDefaultKeyPair')
ExportSnapshot = Action('ExportSnapshot')
GetActiveNames = Action('GetActiveNames')
GetBlueprints = Action('GetBlueprints')
GetBundles = Action('GetBundles')
GetCloudFormationStackRecords = Action('GetCloudFormationStackRecords')
GetDisk = Action('GetDisk')
GetDiskSnapshot = Action('GetDiskSnapshot')
GetDiskSnapshots = Action('GetDiskSnapshots')
GetDisks = Action('GetDisks')
GetDomain = Action('GetDomain')
GetDomains = Action('GetDomains')
GetExportSnapshotRecords = Action('GetExportSnapshotRecords')
GetInstance = Action('GetInstance')
GetInstanceAccessDetails = Action('GetInstanceAccessDetails')
GetInstanceMetricData = Action('GetInstanceMetricData')
GetInstancePortStates = Action('GetInstancePortStates')
GetInstanceSnapshot = Action('GetInstanceSnapshot')
GetInstanceSnapshots = Action('GetInstanceSnapshots')
GetInstanceState = Action('GetInstanceState')
GetInstances = Action('GetInstances')
GetKeyPair = Action('GetKeyPair')
GetKeyPairs = Action('GetKeyPairs')
GetLoadBalancer = Action('GetLoadBalancer')
GetLoadBalancerMetricData = Action('GetLoadBalancerMetricData')
GetLoadBalancerTlsCertificates = Action('GetLoadBalancerTlsCertificates')
GetLoadBalancers = Action('GetLoadBalancers')
GetOperation = Action('GetOperation')
GetOperations = Action('GetOperations')
GetOperationsForResource = Action('GetOperationsForResource')
GetRegions = Action('GetRegions')
GetRelationalDatabase = Action('GetRelationalDatabase')
GetRelationalDatabaseBlueprints = \
    Action('GetRelationalDatabaseBlueprints')
GetRelationalDatabaseBundles = Action('GetRelationalDatabaseBundles')
GetRelationalDatabaseEvents = Action('GetRelationalDatabaseEvents')
GetRelationalDatabaseLogEvents = Action('GetRelationalDatabaseLogEvents')
GetRelationalDatabaseLogStreams = \
    Action('GetRelationalDatabaseLogStreams')
GetRelationalDatabaseMasterUserPassword = \
    Action('GetRelationalDatabaseMasterUserPassword')
GetRelationalDatabaseMetricData = \
    Action('GetRelationalDatabaseMetricData')
GetRelationalDatabaseParameters = \
    Action('GetRelationalDatabaseParameters')
GetRelationalDatabaseSnapshot = Action('GetRelationalDatabaseSnapshot')
GetRelationalDatabaseSnapshots = Action('GetRelationalDatabaseSnapshots')
GetRelationalDatabases = Action('GetRelationalDatabases')
GetStaticIp = Action('GetStaticIp')
GetStaticIps = Action('GetStaticIps')
ImportKeyPair = Action('ImportKeyPair')
IsVpcPeered = Action('IsVpcPeered')
OpenInstancePublicPorts = Action('OpenInstancePublicPorts')
PeerVpc = Action('PeerVpc')
PutInstancePublicPorts = Action('PutInstancePublicPorts')
RebootInstance = Action('RebootInstance')
RebootRelationalDatabase = Action('RebootRelationalDatabase')
ReleaseStaticIp = Action('ReleaseStaticIp')
StartInstance = Action('StartInstance')
StartRelationalDatabase = Action('StartRelationalDatabase')
StopInstance = Action('StopInstance')
StopRelationalDatabase = Action('StopRelationalDatabase')
TagResource = Action('TagResource')
UnpeerVpc = Action('UnpeerVpc')
UntagResource = Action('UntagResource')
UpdateDomainEntry = Action('UpdateDomainEntry')
UpdateLoadBalancerAttribute = Action('UpdateLoadBalancerAttribute')
UpdateRelationalDatabase = Action('UpdateRelationalDatabase')
UpdateRelationalDatabaseParameters = \
    Action('UpdateRelationalDatabaseParameters')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Marketplace'
prefix = 'aws-marketplace'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptAgreementApprovalRequest = Action('AcceptAgreementApprovalRequest')
CancelAgreementRequest = Action('CancelAgreementRequest')
DescribeAgreement = Action('DescribeAgreement')
GetAgreementApprovalRequest = Action('GetAgreementApprovalRequest')
GetAgreementRequest = Action('GetAgreementRequest')
GetAgreementTerms = Action('GetAgreementTerms')
ListAgreementApprovalRequests = Action('ListAgreementApprovalRequests')
ListAgreementRequests = Action('ListAgreementRequests')
RegisterUsage = Action('RegisterUsage')
RejectAgreementApprovalRequest = Action('RejectAgreementApprovalRequest')
SearchAgreements = Action('SearchAgreements')
Subscribe = Action('Subscribe')
Unsubscribe = Action('Unsubscribe')
UpdateAgreementApprovalRequest = Action('UpdateAgreementApprovalRequest')
ViewSubscriptions = Action('ViewSubscriptions')
AcceptAgreementApprovalRequest = Action('AcceptAgreementApprovalRequest')
BatchMeterUsage = Action('BatchMeterUsage')
CancelAgreementRequest = Action('CancelAgreementRequest')
DescribeAgreement = Action('DescribeAgreement')
GetAgreementApprovalRequest = Action('GetAgreementApprovalRequest')
GetAgreementRequest = Action('GetAgreementRequest')
GetAgreementTerms = Action('GetAgreementTerms')
ListAgreementApprovalRequests = Action('ListAgreementApprovalRequests')
ListAgreementRequests = Action('ListAgreementRequests')
MeterUsage = Action('MeterUsage')
RegisterUsage = Action('RegisterUsage')
RejectAgreementApprovalRequest = Action('RejectAgreementApprovalRequest')
ResolveCustomer = Action('ResolveCustomer')
SearchAgreements = Action('SearchAgreements')
UpdateAgreementApprovalRequest = Action('UpdateAgreementApprovalRequest')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Rekognition'
prefix = 'rekognition'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CompareFaces = Action('CompareFaces')
CreateCollection = Action('CreateCollection')
CreateProject = Action('CreateProject')
CreateProjectVersion = Action('CreateProjectVersion')
CreateStreamProcessor = Action('CreateStreamProcessor')
DeleteCollection = Action('DeleteCollection')
DeleteFaces = Action('DeleteFaces')
DeleteProject = Action('DeleteProject')
DeleteProjectVersion = Action('DeleteProjectVersion')
DeleteStreamProcessor = Action('DeleteStreamProcessor')
DescribeCollection = Action('DescribeCollection')
DescribeProjectVersions = Action('DescribeProjectVersions')
DescribeProjects = Action('DescribeProjects')
DescribeStreamProcessor = Action('DescribeStreamProcessor')
DetectCustomLabels = Action('DetectCustomLabels')
DetectFaces = Action('DetectFaces')
DetectLabels = Action('DetectLabels')
DetectModerationLabels = Action('DetectModerationLabels')
DetectText = Action('DetectText')
GetCelebrityInfo = Action('GetCelebrityInfo')
GetCelebrityRecognition = Action('GetCelebrityRecognition')
GetContentModeration = Action('GetContentModeration')
GetFaceDetection = Action('GetFaceDetection')
GetFaceSearch = Action('GetFaceSearch')
GetLabelDetection = Action('GetLabelDetection')
GetPersonTracking = Action('GetPersonTracking')
GetSegmentDetection = Action('GetSegmentDetection')
GetTextDetection = Action('GetTextDetection')
IndexFaces = Action('IndexFaces')
ListCollections = Action('ListCollections')
ListFaces = Action('ListFaces')
ListStreamProcessors = Action('ListStreamProcessors')
RecognizeCelebrities = Action('RecognizeCelebrities')
SearchFaces = Action('SearchFaces')
SearchFacesByImage = Action('SearchFacesByImage')
StartCelebrityRecognition = Action('StartCelebrityRecognition')
StartContentModeration = Action('StartContentModeration')
StartFaceDetection = Action('StartFaceDetection')
StartFaceSearch = Action('StartFaceSearch')
StartLabelDetection = Action('StartLabelDetection')
StartPersonTracking = Action('StartPersonTracking')
StartProjectVersion = Action('StartProjectVersion')
StartSegmentDetection = Action('StartSegmentDetection')
StartStreamProcessor = Action('StartStreamProcessor')
StartTextDetection = Action('StartTextDetection')
StopProjectVersion = Action('StopProjectVersion')
StopStreamProcessor = Action('StopStreamProcessor')
